@@ -369,8 +369,8 @@
 	#define KVI_CONFIG_DEFAULT_GROUP "KVIrc_Config"
 #endif
 
-#define KVI_DEFAULT_FONTSIZE   9
-#define KVI_DEFAULT_FONT       "Sans"
-#define KVI_DEFAULT_FIXED_FONT "Courier New"
+#define KVI_DEFAULT_FONTSIZE   11
+#define KVI_DEFAULT_FONT       "Bitstream Vera Sans"
+#define KVI_DEFAULT_FIXED_FONT "Bitstream Vera Sans Mono"
 
 #endif // _KVI_DEFINES_H_INCLUDED_
