@@ -606,7 +606,7 @@ KviStr::KviStr(const QString &str)
 	QCString tmp = str.local8Bit();
 	const char *ptr = tmp.data();
 #else
-	const char *ptr = str.latin1();
+	const QCString ptr = str.utf8();
 #endif
 	if( ptr ) {
 		m_len = strlen(ptr);
@@ -744,14 +744,14 @@ KviStr & KviStr::operator=(const QString &str)
 {
 #ifdef COMPILE_USE_LOCAL_8BIT_ENCODING
 	QCString tmp = str.local8Bit();
-	const char *p = tmp.data();
+	const char *ptr = tmp.data();
 #else
-	const char *p = str.latin1();
+	const QCString ptr = str.utf8();
 #endif
-	if( p ) {
-		m_len = strlen(p);
+	if( ptr ) {
+		m_len = strlen(ptr);
 		m_ptr = (char *) kvi_realloc(m_ptr, m_len + 1);
-		kvi_fastmove(m_ptr, p, m_len + 1);
+		kvi_fastmove(m_ptr, ptr, m_len + 1);
 	} else {
 		m_ptr = (char *) kvi_realloc(m_ptr, 1);
 		*m_ptr = '\0';
@@ -800,7 +800,7 @@ void KviStr::append(const QString &str)
 	QCString tmp = str.local8Bit();
 	const char *ptr = tmp.data();
 #else
-	const char *ptr = str.latin1();
+	const QCString ptr = str.utf8();
 #endif
 	if( !ptr ) return;
 	int len = strlen(ptr);
