@@ -23,11 +23,19 @@
 
 #include "kvi_application_kde.h"
 
-KviApplication::KviApplication(int argc, char **argv, const char *appname)
-	: KApplication(argc, argv, appname)
+#if KDE_IS_VERSION(3,2,0)
+KviApplication::KviApplication(int argc, char **argv, const char *appName)
+	: KApplication()
+{
+	KApplication::addCmdLineOptions();
+}
+#else
+KviApplication::KviApplication(int argc, char **argv, const char *appName)
+	: KApplication(argc, argv, appName)
 {
 	// Nothing here
 }
+#endif
 
 KviApplication::~KviApplication()
 {
