@@ -21,10 +21,16 @@
 //
 // =============================================================================
 
+#include <kdeversion.h>
+#if KDE_IS_VERSION(3,2,0)
+	#include <kinputdialog.h>
+#else
+	#include <klineeditdlg.h>
+#endif
+
 #include "kvi_lineeditdialog_kde.h"
 
-KviLineEditDialog::KviLineEditDialog(const QString &text, const QString &value, QWidget *parent)
-	: KLineEditDlg(text, value, parent)
+KviLineEditDialog::KviLineEditDialog()
 {
 	// Nothing here
 }
@@ -34,4 +40,12 @@ KviLineEditDialog::~KviLineEditDialog()
 	// Nothing here
 }
 
-#include "m_kvi_lineeditdialog_kde.moc"
+QString KviLineEditDialog::getText(
+	const QString &caption, const QString &text, const QString &value, bool *ok, QWidget *parent)
+{
+#if KDE_IS_VERSION(3,2,0)
+	return KInputDialog::getText(caption, text, value, ok, parent);
+#else
+	return KLineEditDlg::getText(caption, text, value, ok, parent);
+#endif
+}
