@@ -99,7 +99,7 @@ void KviConfig::clearKey(const char *szKey)
 
 void KviConfig::getContentsString(KviStr &buffer)
 {
-	buffer = __tr("Contents of config file ");
+	buffer = _i18n_("Contents of config file ");
 	buffer.append(m_szFileName.ptr());
 	buffer.append('\n');
 	int sections = 0;
@@ -121,13 +121,13 @@ void KviConfig::getContentsString(KviStr &buffer)
 			++sectionKeys;
 			++keys;
 		}
-		KviStr tmp(KviStr::Format, __tr("  Total: %d keys"), sectionKeys);
+		KviStr tmp(KviStr::Format, _i18n_("  Total: %d keys"), sectionKeys);
 		buffer.append(tmp);
 		buffer.append('\n');
 		++iter;
 		++sections;
 	}
-	KviStr tmp(KviStr::Format, __tr("Total: %d keys in %d sections"), keys, sections);
+	KviStr tmp(KviStr::Format, _i18n_("Total: %d keys in %d sections"), keys, sections);
 	buffer.append(tmp);
 }
 
@@ -331,12 +331,12 @@ bool KviConfig::getFont(QFont &font, QString desired)
 {
 	font.setFamily(desired);
 	QFontInfo info(font);
-	return (info.family() == desired);
+	return (info.family().startsWith(desired, false));
 }
 
 QFont KviConfig::getFixedFont()
 {
-	QString desired = "Bitstream Vera Sans Mono";
+	QString desired = KVI_DEFAULT_FIXED_FONT;
 	QFont font(desired);
 	// TODO: Qt seems to ignore this style hint
 	font.setStyleHint(QFont::TypeWriter, QFont::PreferAntialias);
