@@ -1,11 +1,11 @@
 #ifndef _KVI_STRSUB_H_INCLUDED_
 #define _KVI_STRSUB_H_INCLUDED_
 
+// =============================================================================
 //
-//   File : kvi_strsub.h
-//   Last major modification : Fri Oct 29 1999 03:06:26 by munehiro
+//      --- kvi_strsub.h ---
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc IRC client distribution
 //
 //   This program is FREE software. You can redistribute it and/or
 //   modify it under the terms of the GNU General Public License
@@ -19,19 +19,24 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program. If not, write to the Free Software Foundation,
-//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+// =============================================================================
+
+#include <qptrlist.h>
 
-#include <qlist.h>
-#include "kvi_config.h"
 #include "kvi_string.h"
 
-typedef struct KviStrSubItem {
+class KviConfig;
+
+typedef struct
+{
 	KviStr szOriginal;
 	KviStr szSubstitute;
-};
+} KviStrSubItem;
 
-class KviStrSub {
+class KviStrSub
+{
 public:
 	KviStrSub();
 	~KviStrSub();
@@ -39,9 +44,7 @@ public:
 	bool load(KviConfig *cfg);
 	bool save(KviConfig *cfg);
 
-	QList<KviStrSubItem> *m_pList;
-
+	QPtrList<KviStrSubItem> *m_pList;
 };
 
-
-#endif
+#endif // _KVI_STRSUB_H_INCLUDED_
