@@ -1,11 +1,11 @@
-#ifndef _KVI_XUTLIS_H_INCLUDED_
+#ifndef _KVI_XUTILS_H_INCLUDED_
 #define _KVI_XUTILS_H_INCLUDED_
 
+// =============================================================================
 //
-//   File : kvi_xutils.h (/usr/build/NEW_kvirc/kvirc/kvilib/kvi_xutils.h)
-//   Last major modification : Wed Jan 6 1999 14:50:40 by Szymon Stefanek
+//      --- kvi_xutils.h ---
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc IRC client distribution
 //   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -20,31 +20,20 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program. If not, write to the Free Software Foundation,
-//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+// =============================================================================
 
 #undef __kvi_extern
-
 #ifdef _KVI_XUTILS_CPP_
 	#define __kvi_extern
 #else
 	#define __kvi_extern extern
 #endif
 
-#include <X11/Xlib.h>
-#ifdef COMPILE_USE_AA_FONTS
-	#include <X11/Xft/Xft.h>
-#endif
-#include <qpalette.h>
-#include <qwindowdefs.h>
-#include <qrect.h>
+class QPainter;
+class QRect;
 
-#ifdef TrueColor
-#undef TrueColor
-#endif
+__kvi_extern void kvi_drawDragRectangle(QPainter *pa, QRect &rectToDraw, int style = 0);
 
-
-__kvi_extern void kvi_xDraw3dRect(Display *dpy,GC gc,Drawable d,const QColorGroup &cg,int x1,int y1,int x2,int y2,bool bSunken);
-__kvi_extern void kvi_drawDragRectangle(QRect &rectToDraw,Drawable drw = 0,int style = 1);
-
-#endif //_KVI_XUTILS_H_INCLUDED_
+#endif // _KVI_XUTILS_H_INCLUDED_
