@@ -291,13 +291,13 @@ void KviMdiManager::fillWindowMenu()
 		i++;
 	}
 	m_pWindowMenu->insertSeparator();
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("&Cascade Windows")),            this, SLOT(cascadeWindows()));
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("Cascade &Maximized")),          this, SLOT(cascadeMaximized()));
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("Expand &Vertical")),            this, SLOT(expandVertical()));
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("Expand &Horizontal")),          this, SLOT(expandHorizontal()));
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("&Anodine's Tile")),             this, SLOT(tileAnodine()));
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("&Pragma's Tile (Vertical)")),   this, SLOT(tilePragmaVertical()));
-	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(__tr("P&ragma's Tile (Horizontal)")), this, SLOT(tilePragmaHorizontal()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("&Cascade Windows")),            this, SLOT(cascadeWindows()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("Cascade &Maximized")),          this, SLOT(cascadeMaximized()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("Expand &Vertical")),            this, SLOT(expandVertical()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("Expand &Horizontal")),          this, SLOT(expandHorizontal()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("&Anodine's Tile")),             this, SLOT(tileAnodine()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("&Pragma's Tile (Vertical)")),   this, SLOT(tilePragmaVertical()));
+	m_pWindowMenu->insertItem(_CHAR_2_QSTRING(_i18n_("P&ragma's Tile (Horizontal)")), this, SLOT(tilePragmaHorizontal()));
 }
 
 // ================ menuActivated ===============
@@ -530,7 +530,7 @@ void KviMdiManager::tileAllInternal(int maxWnds, bool bHorizontal)
 	int xQuantum = width() / pColstable[numToHandle - 1];
 	if( xQuantum < ((lpTop->minimumSize().width() > KVI_MDI_CHILD_MIN_WIDTH) ? lpTop->minimumSize().width() : KVI_MDI_CHILD_MIN_WIDTH) ) {
 		if( pColrecall[numToHandle - 1] == 0 )
-			debug(__tr("Tile: not enough space"));
+			debug(_i18n_("Tile: not enough space"));
 		else
 			tileAllInternal(pColrecall[numToHandle - 1], bHorizontal);
 		return;
@@ -538,7 +538,7 @@ void KviMdiManager::tileAllInternal(int maxWnds, bool bHorizontal)
 	int yQuantum = height() / pRowstable[numToHandle - 1];
 	if( yQuantum < ((lpTop->minimumSize().height() > KVI_MDI_CHILD_MIN_HEIGHT) ? lpTop->minimumSize().height() : KVI_MDI_CHILD_MIN_HEIGHT) ) {
 		if( pRowrecall[numToHandle - 1] == 0 )
-			debug(__tr("Tile: not enough space"));
+			debug(_i18n_("Tile: not enough space"));
 		else
 			tileAllInternal(pRowrecall[numToHandle - 1], bHorizontal);
 		return;
