@@ -30,8 +30,11 @@ class KviAccel : public QAccel
 {
 	Q_OBJECT
 public:
+	KviAccel(QWidget *, QObject *, const char *psName = 0);
 	KviAccel(QWidget *, const char *);
 	~KviAccel();
+
+	const QKeySequence shortcut(const QString &) const;
 };
 
 #endif // _KVI_ACCEL_QT_H_INCLUDED_
