@@ -119,11 +119,11 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 {
 	KviStr buffer;
 	if( !kvi_loadFile(filename, buffer) ) {
-		error = __tr("Unable to load file");
+		error = _i18n_("Unable to load file");
 		return false;
 	}
 	if( !kvi_strEqualCSN(KVI_MAGIC_STRING, buffer.ptr(), KVI_MAGIC_STRING_LENGTH) ) {
-		error = __tr("Invalid magic");
+		error = _i18n_("Invalid magic");
 		return false; // Not a KVIrc file
 	}
 	buffer.cutLeft(KVI_MAGIC_STRING_LENGTH);
@@ -138,7 +138,7 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 		// ...
 		// \n[ENDALIAS]\n
 		if( !kvi_strEqualCIN("[ALIAS ", buffer.ptr(), 7) ) {
-			error = __tr("Unrecognized [ALIAS] label.");
+			error = _i18n_("Unrecognized [ALIAS] label.");
 			return false;
 		}
 		buffer.cutLeft(7);
@@ -149,13 +149,13 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 
 		if( !buffer.getToken(a->szName, ' ') ) {
 			// There must be at least another token
-			error = __tr("Syntax error in [ALIAS] label");
+			error = _i18n_("Syntax error in [ALIAS] label");
 			if( a ) delete a;
 			return false;
 		}
 		if( a->szName.isEmpty() ) {
 			// Syntax error somewhere
-			error = __tr("Empty alias name?");
+			error = _i18n_("Empty alias name?");
 			if( a ) delete a;
 			return false;
 		}
@@ -163,7 +163,7 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 		buffer.stripLeftWhiteSpace(); // Be flexible... allow some spaces... for manual editing by experts :)
 
 		if( !kvi_strEqualCIN("bytes ", buffer.ptr(), 6) ) {
-			error = __tr("Syntax error in [ALIAS] label (alias length)");
+			error = _i18n_("Syntax error in [ALIAS] label (alias length)");
 			if( a ) delete a;
 			return false;
 		}
@@ -171,14 +171,14 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 		buffer.stripLeftWhiteSpace(); // Be flexible... allow some spaces... for manual editing by experts :)
 
 		if( !isdigit(*(buffer.ptr())) ) {
-			error = __tr("Syntax error in [ALIAS] label (digit expected)");
+			error = _i18n_("Syntax error in [ALIAS] label (digit expected)");
 			if( a ) delete a;
 			return false;
 		}
 
 		KviStr numBytes;
 		if( !buffer.getToken(numBytes, ']') ) {
-			error = __tr("Syntax error in [ALIAS] label (cannot extract alias length)");
+			error = _i18n_("Syntax error in [ALIAS] label (cannot extract alias length)");
 			if( a ) delete a;
 			return false;
 		}
@@ -187,14 +187,14 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 		int bytes = numBytes.toInt(&bOk);
 		if( !bOk ) {
 			// Syntax error again... someone messed with the file
-			error = __tr("Unrecogized token ");
+			error = _i18n_("Unrecogized token ");
 			error += numBytes;
 			if( a ) delete a;
 			return false;
 		}
 		buffer.cutLeft(1); // Cut the \n
 		if( buffer.len() < bytes ) {
-			error = __tr("Alias buffer smaller than declared length (");
+			error = _i18n_("Alias buffer smaller than declared length (");
 			error += numBytes;
 			error += ")";
 			if( a ) delete a;
@@ -204,7 +204,7 @@ bool KviAliasManager::load(const char *filename, KviStr &error)
 		buffer.cutLeft(bytes);
 
 		if( !kvi_strEqualCIN("\n[ENDALIAS]", buffer.ptr(), 11) ) {
-			error = __tr("Unrecognized [ENDALIAS] label");
+			error = _i18n_("Unrecognized [ENDALIAS] label");
 			if( a ) delete a;
 			return false;
 		}
