@@ -1,11 +1,11 @@
 #ifndef _KVI_ANTISPAM_H_INCLUDED_
 #define _KVI_ANTISPAM_H_INCLUDED_
 
+// =============================================================================
 //
-//   File : kvi_antispam.h (/usr/build/NEW_kvirc/kvirc/src/kvirc/kvi_antispam.h)
-//   Last major modification : Sun Apr 18 1999 05:36:09 by Szymon Stefanek
+//      --- kvi_antispam.h ---
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc IRC client distribution
 //   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -20,10 +20,12 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program. If not, write to the Free Software Foundation,
-//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+// =============================================================================
+
 #ifndef _KVI_ANTISPAM_CPP_
 	extern bool kvi_mayBeSpamMsg(const char *text);
 #endif
 
-#endif //!_KVI_ANTISPAM_H_INCLUDED_
+#endif // _KVI_ANTISPAM_H_INCLUDED_
