@@ -220,18 +220,16 @@ bool KviApp::findLocalKVIrcDirectory()
 
 bool KviApp::loadDirectories()
 {
+	// Init locale
+	if( !kvi_initLocale(this) )
+		debug("[KVIrc]: cannot initialize the localization engine");
 	// First find the global (readable) one...
 	findGlobalKVIrcDirectory();
-	// Init locale
-	KviStr szLocalePath = m_szGlobalKVIrcDir;
-	szLocalePath.append("/locale/");
-	if( !kvi_initLocale(this, szLocalePath.ptr()) )
-		debug("[KVIrc]: cannot initialize the localization engine");
 
 	// Now look for the local (writable) one
 	if( !findLocalKVIrcDirectory() ) {
 		// We must do the setup... ask the user..
-		KviStr tmp(KviStr::Format, __tr(
+		KviStr tmp(KviStr::Format, _i18n_(
 			"Welcome to the KVIrc setup program!\n"
 			"You will be asked to choose an existing directory now.\n"
 			"A '%s' subdirectory will be created inside. KVIrc will\n"
@@ -240,28 +238,28 @@ bool KviApp::loadDirectories()
 			KVI_LOCAL_KVIRC_SUBDIRECTORY_NAME
 		);
 
-		KviMessageBox::information(tmp.ptr(), __tr("KVIrc Setup"));
+		KviMessageBox::information(tmp.ptr(), _i18n_("KVIrc Setup"));
 		KviStr home = QDir::homeDirPath();
 
 		m_szLocalKVIrcDir = kvi_askForDirectoryName(home.ptr());
 		if( m_szLocalKVIrcDir.isEmpty() ) {
-			warningBox(__tr("Setup aborted."));
+			warningBox(_i18n_("Setup aborted."));
 			return false;
 		}
 		m_szLocalKVIrcDir.ensureLastCharIs('/');
 		m_szLocalKVIrcDir += KVI_LOCAL_KVIRC_SUBDIRECTORY_NAME;
 		// Now create the dir...
 		if( kvi_directoryExists(m_szLocalKVIrcDir.ptr()) ) {
-			tmp.sprintf(__tr(
+			tmp.sprintf(_i18n_(
 				"The '%s' subdirectory already exists,\n"
 				"maybe from a previous KVIrc installation.\n"
 				"If you experience any problems, try deleting the old directory."),
 				KVI_LOCAL_KVIRC_SUBDIRECTORY_NAME
 			);
-			KviMessageBox::information(tmp.ptr(), __tr("KVIrc Setup"));
+			KviMessageBox::information(tmp.ptr(), _i18n_("KVIrc Setup"));
 		} else if( !kvi_makeDir(m_szLocalKVIrcDir.ptr()) ) {
 			// Failed to make the dir...
-			warningBox(__tr(
+			warningBox(_i18n_(
 				"Could not make the directory %s.\n"
 				"Trying alternate default $HOME/%s"),
 				m_szLocalKVIrcDir.ptr(), KVI_LOCAL_KVIRC_SUBDIRECTORY_NAME
@@ -270,15 +268,15 @@ bool KviApp::loadDirectories()
 			m_szLocalKVIrcDir.ensureLastCharIs('/');
 			m_szLocalKVIrcDir += KVI_LOCAL_KVIRC_SUBDIRECTORY_NAME;
 			if( kvi_directoryExists(m_szLocalKVIrcDir.ptr()) ) {
-				tmp.sprintf(__tr(
+				tmp.sprintf(_i18n_(
 					"The '%s' subdirectory already exists, maybe from a previous KVIrc installation.\n"
 					"It can be used, but if you experience any problems, try deleting the old directory\n."
 					"and repeating the setup."),
 					KVI_LOCAL_KVIRC_SUBDIRECTORY_NAME
 				);
-				KviMessageBox::information(tmp.ptr(), __tr("KVIrc Setup"));
+				KviMessageBox::information(tmp.ptr(), _i18n_("KVIrc Setup"));
 			} else if( !kvi_makeDir(m_szLocalKVIrcDir.ptr()) ) {
-				warningBox(__tr(
+				warningBox(_i18n_(
 					"Could not make directory $HOME/%s.\n"
 					"Bad luck... you have some problems with your environment, \n"
 					"the $HOME/%s path is not writable or is not a directory.\n"
@@ -289,7 +287,7 @@ bool KviApp::loadDirectories()
 			}
 		}
 		if( !kvi_directoryIsWritable(m_szLocalKVIrcDir.ptr()) ) {
-			warningBox(__tr(
+			warningBox(_i18n_(
 				"Could not write to directory %s.\n"
 				"Setup aborted."),
 				m_szLocalKVIrcDir.ptr()
