@@ -118,7 +118,7 @@ KviChannel::KviChannel(KviFrame *lpFrm, const char *name)
 	m_pTopSplitter->setOpaqueResize();
 
 	m_pTopicLabel  = new KviChanLabel(
-		__tr("[ Channel topic unknown (No topic message received) ]"),
+		_i18n_("[ Channel topic unknown (No topic message received) ]"),
 		m_pTopSplitter, "topic_label"
 	);
 	setTopicToolTip();
@@ -270,9 +270,9 @@ void KviChannel::usersLabelRightClicked()
 	if( !m_pMasksEditPopup )
 		m_pMasksEditPopup = new KviPopupMenu(this);
 	m_pMasksEditPopup->clear();
-	m_pMasksEditPopup->insertItem(__tr("&Ban List"),              this, SLOT(doEditBans()));
-	m_pMasksEditPopup->insertItem(__tr("Ban &Exception List"),    this, SLOT(doEditBanExceptions()));
-	m_pMasksEditPopup->insertItem(__tr("&Invite Exception List"), this, SLOT(doEditInviteExceptions()));
+	m_pMasksEditPopup->insertItem(_i18n_("&Ban List"),              this, SLOT(doEditBans()));
+	m_pMasksEditPopup->insertItem(_i18n_("Ban &Exception List"),    this, SLOT(doEditBanExceptions()));
+	m_pMasksEditPopup->insertItem(_i18n_("&Invite Exception List"), this, SLOT(doEditInviteExceptions()));
 	m_pMasksEditPopup->popup(QCursor::pos());
 }
 
@@ -283,7 +283,7 @@ void KviChannel::doEditBans()
 
 	m_pBanEditor = new KviMaskEditor(m_pSplitter);
 	m_pSplitter->moveToFirst(m_pBanEditor);
-	m_pBanEditor->doEdit(this, SLOT(banEditCompleted(const char *)), m_pBanList, __tr("Ban Mask"), m_bModeChangeEnabled);
+	m_pBanEditor->doEdit(this, SLOT(banEditCompleted(const char *)), m_pBanList, _i18n_("Ban Mask"), m_bModeChangeEnabled);
 	m_iLastMasksEdited = KVI_MASKEDIT_BANS;
 }
 
@@ -296,7 +296,7 @@ void KviChannel::doEditBanExceptions()
 	m_pSplitter->moveToFirst(m_pBanExceptEditor);
 	m_pBanExceptEditor->doEdit(
 		this, SLOT(banExceptEditCompleted(const char *)),
-		m_pExceptionList, __tr("Ban Exception Mask"), m_bModeChangeEnabled
+		m_pExceptionList, _i18n_("Ban Exception Mask"), m_bModeChangeEnabled
 	);
 	m_iLastMasksEdited = KVI_MASKEDIT_BANEXCEPTIONS;
 }
@@ -310,7 +310,7 @@ void KviChannel::doEditInviteExceptions()
 	m_pSplitter->moveToFirst(m_pInviteExceptEditor);
 	m_pInviteExceptEditor->doEdit(
 		this, SLOT(inviteExceptEditCompleted(const char *)),
-			m_pInviteExceptionList, __tr("Invite Exception Mask"), m_bModeChangeEnabled);
+			m_pInviteExceptionList, _i18n_("Invite Exception Mask"), m_bModeChangeEnabled);
 	m_iLastMasksEdited = KVI_MASKEDIT_INVITEEXCEPTIONS;
 }
 
@@ -431,25 +431,17 @@ void KviChannel::setTopicToolTip()
 	kvi_free(str);
 	QString s;
 	if( tmp.hasData() ) {
-		s = _CHAR_2_QSTRING(__tr("Topic: "));
+		s = _CHAR_2_QSTRING(_i18n_("Topic: "));
 		s.append(_CHAR_2_QSTRING(tmp.ptr()));
-	} else s = _CHAR_2_QSTRING(__tr("No topic is set"));
+	} else s = _CHAR_2_QSTRING(_i18n_("No topic is set"));
 	s.append("\n");
-	s.append(m_bTopicChangeEnabled ? _CHAR_2_QSTRING(__tr("Double-click to edit")) : _CHAR_2_QSTRING(__tr("You cannot edit it")));
+	s.append(m_bTopicChangeEnabled ? _CHAR_2_QSTRING(_i18n_("Double-click to edit")) : _CHAR_2_QSTRING(_i18n_("You cannot edit it")));
 	QToolTip::add(m_pTopicLabel, s);
 }
 
 void KviChannel::setTopic(const char *text)
 {
-	QString *pHist = new QString(text);
-	__range_valid(pHist);
 	m_pTopicLabel->setText(text);
-	if( m_pTopicEditor ) {
-		m_pTopicEditor->m_pHistory->insert(0, pHist);
-		if( m_pTopicEditor->m_pHistory->count() > 10 )
-			m_pTopicEditor->m_pHistory->removeLast();
-	}
-	if( pHist ) delete pHist;
 	setTopicToolTip();
 }
 
@@ -464,9 +456,9 @@ void KviChannel::setTopicChangeEnabled(bool bEnabled)
 void KviChannel::setModeToolTip()
 {
 	QToolTip::remove(m_pModeLabel);
-	QString s = __tr("Current channel mode");
+	QString s = _i18n_("Current channel mode");
 	if( m_bModeChangeEnabled )
-		s.append(__tr("\nDouble-click to edit"));
+		s.append(_i18n_("\nDouble-click to edit"));
 	QToolTip::add(m_pModeLabel, s);
 }
 
@@ -655,7 +647,7 @@ void KviChannel::checkSyncComplete()
 		}
 
 		if( g_pOptions->m_bShowChannelSyncTime && (!bHalt) ) {
-			output(KVI_OUT_INTERNAL, __tr("Channel synchronized in %d.%d seconds"), secs, msecs);
+			output(KVI_OUT_INTERNAL, _i18n_("Channel synchronized in %d.%d seconds"), secs, msecs);
 		}
 	}
 }
@@ -944,31 +936,31 @@ bool KviChannel::kickDumpChanStatus(
 	if( !f.open(IO_WriteOnly) )
 		return false;
 
-	KviStr tmp(KviStr::Format, __tr("Kick log for %s on channel %s\n"), kicked, caption());
+	KviStr tmp(KviStr::Format, _i18n_("Kick log for %s on channel %s\n"), kicked, caption());
 	f.writeBlock(tmp.ptr(), tmp.len());
 	QDateTime tm(QDateTime::currentDateTime());
 	KviStr d = tm.toString();
-	tmp.sprintf(__tr("Written at %s\n\n"), d.ptr());
+	tmp.sprintf(_i18n_("Written at %s\n\n"), d.ptr());
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp.sprintf(__tr("You were kicked from %s by %s [%s]\n"), caption(), kicker, kicker_mask);
+	tmp.sprintf(_i18n_("You were kicked from %s by %s [%s]\n"), caption(), kicker, kicker_mask);
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp.sprintf(__tr("Kick reason: %s\n\n"), reason);
+	tmp.sprintf(_i18n_("Kick reason: %s\n\n"), reason);
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp = __tr("Channel topic:\n");
+	tmp = _i18n_("Channel topic:\n");
 	f.writeBlock(tmp.ptr(), tmp.len());
 	tmp = m_pTopicLabel->text();
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp = __tr("\nChannel mode:\n");
+	tmp = _i18n_("\nChannel mode:\n");
 	f.writeBlock(tmp.ptr(), tmp.len());
 	tmp = m_pModeLabel->text();
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp = __tr("\nChannel text buffer:\n");
+	tmp = _i18n_("\nChannel text buffer:\n");
 	f.writeBlock(tmp.ptr(), tmp.len());
 	m_pView->getTextBuffer(tmp);
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp.sprintf(__tr("You were kicked from %s by %s [%s]: %s\n\n"), caption(), kicker, kicker_mask, reason);
+	tmp.sprintf(_i18n_("You were kicked from %s by %s [%s]: %s\n\n"), caption(), kicker, kicker_mask, reason);
 	f.writeBlock(tmp.ptr(), tmp.len());
-	tmp = __tr("Channel user list:\n");
+	tmp = _i18n_("Channel user list:\n");
 	f.writeBlock(tmp.ptr(), tmp.len());
 	unsigned int num = 0;
 	for( KviIrcUser *pU = m_pListBox->firstUser(); pU; pU = m_pListBox->nextUser() ) {
