@@ -1,6 +1,6 @@
 // =============================================================================
 //
-//      --- kvi_app_quickhelp.cpp ---
+//      --- kvi_frame_quickhelp.cpp ---
 //
 //   This file is part of the KVIrc IRC client distribution
 //   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
@@ -36,7 +36,6 @@
 
 #include <X11/Xlib.h> // For XGrabServer, XGrabPointer, etc.
 
-// TODO: update this with the latest code from the Qt WhatIsThis module
 void KviFrame::slot_whatIsThisRequest()
 {
 	// Own implementation of the whatsThis idea from Qt.
@@ -61,7 +60,7 @@ void KviFrame::slot_whatIsThisRequest()
 	if( last ) {
 		lastRect = last->rect();
 		QPainter pa(last);
-		kvi_drawDragRectangle(&pa, lastRect);
+		kvi_drawDragRectangle(&pa, lastRect, 1);
 	}
 
 	// Now loop until the user clicks.
@@ -77,14 +76,16 @@ void KviFrame::slot_whatIsThisRequest()
 		if( last != w ) {
 			if( last ) {
 				QPainter pa(last);
-				kvi_drawDragRectangle(&pa, lastRect);
+				kvi_drawDragRectangle(&pa, lastRect, 1);
 			}
 			if( w ) {
 				QPainter pa(w);
 				lastRect = w->rect();
-				kvi_drawDragRectangle(&pa, lastRect);
+				kvi_drawDragRectangle(&pa, lastRect, 1);
 			}
 			last = w;
+			// Reset timer if the user is still moving the mouse
+			tm = QTime::currentTime();
 		}
 		if( tm.msecsTo(QTime::currentTime()) > KVI_WHATISTHIS_SELECTION_TIMEOUT ) {
 			bInTime = false;
@@ -93,7 +94,7 @@ void KviFrame::slot_whatIsThisRequest()
 	}
 	if( last ) {
 		QPainter pa(last);
-		kvi_drawDragRectangle(&pa, lastRect);
+		kvi_drawDragRectangle(&pa, lastRect, 1);
 	}
 
 	XUngrabPointer(qt_xdisplay(), CurrentTime);
