@@ -1,11 +1,11 @@
 #ifndef _KVI_HELPQML_H_INCLUDED_
 #define _KVI_HELPQML_H_INCLUDED_
 
+// =============================================================================
 //
-//   File : kvi_helpqml.h (/usr/build/NEW_kvirc/kvirc/src/kvirc/kvi_helpqml.h)
-//   Last major modification : Thu Mar 25 1999 19:08:30 by Szymon Stefanek
+//      --- kvi_helpqml.h ---
 //
-//   This file is part of the KVirc irc client distribution
+//   This file is part of the KVIrc IRC client distribution
 //   Copyright (C) 1999-2000 Szymon Stefanek (stefanek@tin.it)
 //
 //   This program is FREE software. You can redistribute it and/or
@@ -20,29 +20,19 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program. If not, write to the Free Software Foundation,
-//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //
+// =============================================================================
 
-#include <qmime.h>
 #include <qstylesheet.h>
 
-/*
-class KviHelpQMLProvider : public QMimeSourceFactory
-{
-public:
-	KviHelpQMLProvider();
-	~KviHelpQMLProvider();
-public:
-	virtual const QMimeSource* data(const QString& abs_name) const;
-};
-*/
-class KviHelpQMLStyleSheet : public QStyleSheet
+class KviHelpQML : public QStyleSheet
 {
 	Q_OBJECT
 public:
-	KviHelpQMLStyleSheet(QObject *parent);
-	~KviHelpQMLStyleSheet();
+	KviHelpQML(QObject *parent);
+	~KviHelpQML();
 	virtual void error(const QString &err) const;
 };
 
-#endif //!_KVI_HELPQML_H_INCLUDED_
+#endif // _KVI_HELPQML_H_INCLUDED_
