@@ -65,42 +65,42 @@ KviHelpWindow::KviHelpWindow(KviFrame *pFrm, QWidget *parent, const char *name)
 
 	createBrowser();
 
-	m_pToolBar = new KviToolBar(__tr("Help toolbar"), pFrm, this, Qt::Unmanaged, false, "help_toolbar");
+	m_pToolBar = new KviToolBar(_i18n_("Help toolbar"), pFrm, this, Qt::Unmanaged, false, "help_toolbar");
 
 	m_pToolBar->insertButton(
 		tb_close, m_closeButton, SIGNAL(clicked()), m_pFrame, SLOT(closeHelpBrowser()), true, 	 
-		__tr("Close"), __tr("Closes the help window") 	 
+		_i18n_("Close"), _i18n_("Closes the help window") 	 
 	);
 
 	m_pToolBar->insertButton(
 		tb_index, m_homeButton, SIGNAL(clicked()), this, SLOT(showIndex()), true,
-		__tr("Index"), __tr("Shows the help index")
+		_i18n_("Index"), _i18n_("Shows the help index")
 	);
 
 	m_pToolBar->insertButton(
 		tb_back, m_backButton, SIGNAL(clicked()), m_pBrowser, SLOT(backward()), false,
-		__tr("Back"), __tr("Shows the previous document")
+		_i18n_("Back"), _i18n_("Shows the previous document")
 	);
 
 	// Icon needs to be a QPixmap here, or setEnabled(...) will not work
 	m_pToolBar->insertButton(
 		tb_forward, m_forwardButton, SIGNAL(clicked()), m_pBrowser, SLOT(forward()), false,
-		__tr("Forward") , __tr("Shows the next document")
+		_i18n_("Forward") , _i18n_("Shows the next document")
 	);
 
 	m_pToolBar->insertButton(
 		tb_copy, m_copyButton, SIGNAL(clicked()), this, SLOT(copyToClipboard()), true,
-		 __tr("Copy"), __tr("Copy to clipboard")
+		 _i18n_("Copy"), _i18n_("Copy to clipboard")
 	);
 
 	m_pToolBar->insertLined(
-		"", m_inputField, SIGNAL(returnPressed()), this, SLOT(doExactSearch()), true, __tr("Search string")
+		"", m_inputField, SIGNAL(returnPressed()), this, SLOT(doExactSearch()), true, _i18n_("Search string")
 	);
 	m_pToolBar->setItemAutoSized(m_inputField);
 
 	m_pToolBar->insertButton(
 		tb_search, m_searchButton, SIGNAL(clicked()), this, SLOT(doExactSearch()), true,
-		__tr("Search"), __tr("Search the documentation")
+		_i18n_("Search"), _i18n_("Search the documentation")
 	);
 
 	m_pSearchJob = 0;
@@ -202,7 +202,7 @@ void KviHelpWindow::doExactSearchForString(const char *str)
 	if( !m_pSearchJob->run(tmp.ptr(), false, true) ) {
 		delete m_pSearchJob;
 		m_pSearchJob = 0;
-		g_pApp->warningBox(__tr("Could not execute command\n%s"), tmp.ptr());
+		g_pApp->warningBox(_i18n_("Could not execute command\n%s"), tmp.ptr());
 	} else m_pToolBar->setItemEnabled(m_searchButton, false);
 }
 
