@@ -193,7 +193,7 @@ void KviInput::dragEnterEvent(QDragEnterEvent *e)
 {
 	if( QUriDrag::canDecode(e) ) {
 		e->accept(true);
-		m_pParent->m_pFrm->m_pStatusBar->tempText(__tr("Drop the file to /PARSE it"), 5000);
+		m_pParent->m_pFrm->m_pStatusBar->tempText(_i18n_("Drop the file to /PARSE it"), 5000);
 	} else e->accept(false);
 }
 
@@ -1115,10 +1115,10 @@ void KviInput::completion(bool bShift)
 
 	if( iMatches != 1 ) {
 		if( iMatches == 0 )
-			m_pParent->output(KVI_OUT_INTERNAL, __tr("[Completion]: no matches"));
+			m_pParent->output(KVI_OUT_INTERNAL, _i18n_("[Completion]: no matches"));
 		else {
 			multiple.toLower();
-			m_pParent->output(KVI_OUT_INTERNAL, __tr("[Completion]: multiple matches: %s"), multiple.ptr());
+			m_pParent->output(KVI_OUT_INTERNAL, _i18n_("[Completion]: multiple matches: %s"), multiple.ptr());
 		}
 	}
 
