@@ -2032,8 +2032,8 @@ void KviIrcView::findNext(const char *text)
 		} while( l != start );
 	}
 	KviMessageBox::sorry(
-		_CHAR_2_QSTRING(__tr("Text not found")),
-		_CHAR_2_QSTRING(__tr("Find")),
+		_CHAR_2_QSTRING(_i18n_("Text not found")),
+		_CHAR_2_QSTRING(_i18n_("Find")),
 		this
 	);
 }
@@ -2068,8 +2068,8 @@ void KviIrcView::findPrev(const char *text)
 		} while( l != start );
 	}
 	KviMessageBox::sorry(
-		_CHAR_2_QSTRING(__tr("Text not found")),
-		_CHAR_2_QSTRING(__tr("Find")),
+		_CHAR_2_QSTRING(_i18n_("Text not found")),
+		_CHAR_2_QSTRING(_i18n_("Find")),
 		this
 	);
 }
@@ -2178,13 +2178,13 @@ void KviIrcView::mouseMoveEvent(QMouseEvent *e)
 			m_pLastLinkUnderMouse = newLinkUnderMouse;
 			if( m_pLastLinkUnderMouse ) {
 				KviStr dbl, rght;
-				KviStr tmp(__tr("Link:"));
+				KviStr tmp(_i18n_("Link:"));
 				getDoubleClickCommand(dbl, m_pLastLinkUnderMouse->attr_ptr->escape_cmd);
 				if( dbl.hasData() )
-					tmp.append(KviStr(KviStr::Format, __tr(" double-click: \"%s\""), dbl.ptr()));
+					tmp.append(KviStr(KviStr::Format, _i18n_(" double-click: \"%s\""), dbl.ptr()));
 				getRightClickCommand(rght, m_pLastLinkUnderMouse->attr_ptr->escape_cmd);
 				if( rght.hasData() )
-					tmp.append(KviStr(KviStr::Format, __tr(" right click: \"%s\""), rght.ptr()));
+					tmp.append(KviStr(KviStr::Format, _i18n_(" right click: \"%s\""), rght.ptr()));
 				m_pFrm->m_pStatusBar->tempText(tmp.ptr(), 5000);
 
 				if( rectTop < 0 )
