@@ -50,9 +50,9 @@ KviLinksWindow::KviLinksWindow(KviFrame *lpFrm)
 	m_pSplitter = new QSplitter(QSplitter::Vertical, this);
 	m_pSplitter->setOpaqueResize();
 	m_pListView = new KviListView(m_pSplitter);
-	m_pListView->addColumn(__tr("Link"));
-	m_pListView->addColumn(__tr("Hops"), true); // Numeric column
-	m_pListView->addColumn(__tr("Description"));
+	m_pListView->addColumn(_i18n_("Link"));
+	m_pListView->addColumn(_i18n_("Hops"), true); // Numeric column
+	m_pListView->addColumn(_i18n_("Description"));
 	m_pListView->setRootIsDecorated(true);
 	connect(m_pListView,
 		SIGNAL(rightButtonPressed(KviListViewItem *, const QPoint &, int)),
@@ -82,9 +82,9 @@ void KviLinksWindow::endOfLinks()
 	m_pListView->clear();
 	m_pListView->setSorting(-1);
 
-	outputNoFmt(KVI_OUT_INTERNAL, __tr("======================"));
-	outputNoFmt(KVI_OUT_INTERNAL, __tr("Received end of links."));
-	outputNoFmt(KVI_OUT_INTERNAL, __tr("======================"));
+	outputNoFmt(KVI_OUT_INTERNAL, _i18n_("======================"));
+	outputNoFmt(KVI_OUT_INTERNAL, _i18n_("Received end of links."));
+	outputNoFmt(KVI_OUT_INTERNAL, _i18n_("======================"));
 
 	KviListViewItem *it   = 0;
 	KviListViewItem *root = 0;
@@ -107,7 +107,7 @@ void KviLinksWindow::endOfLinks()
 		if( l->hops == 0 )
 			root = new KviListViewItem(m_pListView,
 				_CHAR_2_QSTRING(l->host.ptr()),
-				__tr("0"),
+				_i18n_("0"),
 				_CHAR_2_QSTRING(l->description.ptr())
 			);
 		else {
@@ -130,18 +130,18 @@ void KviLinksWindow::endOfLinks()
 			it = insertLink(l);
 			if( !it ) {
 				output(KVI_OUT_ERROR,
-					__tr("Broken link: missing parent (%s) for %s (%d hops): %s (used /LINKS <mask>?)"),
+					_i18n_("Broken link: missing parent (%s) for %s (%d hops): %s (used /LINKS <mask>?)"),
 					l->parent.ptr(), l->host.ptr(), l->hops, l->description.ptr()
 				);
 				brokenLinks++;
-				KviStr tmp(KviStr::Format, __tr("%s: parent link %s"), l->description.ptr(), l->parent.ptr());
+				KviStr tmp(KviStr::Format, _i18n_("%s: parent link %s"), l->description.ptr(), l->parent.ptr());
 				KviStr tmp2(KviStr::Format, "%d", l->hops);
 				if( root )
 					it = new KviListViewItem(m_pListView, root,
 						_CHAR_2_QSTRING(l->host.ptr()), _CHAR_2_QSTRING(tmp2.ptr()), _CHAR_2_QSTRING(tmp.ptr())
 					);
 				else {
-					outputNoFmt(KVI_OUT_ERROR, __tr("Warning: no root link was sent by the server: stats may be invalid"));
+					outputNoFmt(KVI_OUT_ERROR, _i18n_("Warning: no root link was sent by the server: stats may be invalid"));
 					it = new KviListViewItem(m_pListView,
 						_CHAR_2_QSTRING(l->host.ptr()), _CHAR_2_QSTRING(tmp2.ptr()), _CHAR_2_QSTRING(tmp.ptr())
 					);
@@ -175,23 +175,23 @@ void KviLinksWindow::endOfLinks()
 
 	if( root ) {
 		KviStr tmp = root->text(0);
-		output(KVI_OUT_INTERNAL, __tr("%c%cLinks for %s"), KVI_TEXT_BOLD, KVI_TEXT_UNDERLINE, tmp.ptr());
+		output(KVI_OUT_INTERNAL, _i18n_("%c%cLinks for %s"), KVI_TEXT_BOLD, KVI_TEXT_UNDERLINE, tmp.ptr());
 		outputNoFmt(KVI_OUT_INTERNAL, "======================");
-		output(KVI_OUT_INTERNAL, __tr("Total hosts: %d"), totalHosts);
-		output(KVI_OUT_INTERNAL, __tr("Direct links: %d (%d.%d%)"), directLinks, directProcent / 100, directProcent % 100);
+		output(KVI_OUT_INTERNAL, _i18n_("Total hosts: %d"), totalHosts);
+		output(KVI_OUT_INTERNAL, _i18n_("Direct links: %d (%d.%d%)"), directLinks, directProcent / 100, directProcent % 100);
 		output(KVI_OUT_INTERNAL,
-			__tr("Near links (1-3 hops): %d (%d.%d%)"), nearLinks, nearProcent / 100, nearProcent % 100
+			_i18n_("Near links (1-3 hops): %d (%d.%d%)"), nearLinks, nearProcent / 100, nearProcent % 100
 		);
 		output(KVI_OUT_INTERNAL,
-			__tr("Mid-range links (4-6 hops): %d (%d.%d%)"), midLinks, midProcent / 100, midProcent % 100
+			_i18n_("Mid-range links (4-6 hops): %d (%d.%d%)"), midLinks, midProcent / 100, midProcent % 100
 		);
-		output(KVI_OUT_INTERNAL, __tr("Far links (7+ hops): %d (%d.%d%)"), farLinks, farProcent / 100, farProcent % 100);
-		output(KVI_OUT_INTERNAL, __tr("Broken (unknown) links: %d"), brokenLinks);
-		output(KVI_OUT_INTERNAL, __tr("Max links per host: %d [%s]"), maxLinks, szMaxLinks.ptr());
-		output(KVI_OUT_INTERNAL, __tr("Total links: %d"), totalHops);
-		output(KVI_OUT_INTERNAL, __tr("Maximum hops: %d [%s]"), maxHops, szMaxHop.ptr());
-		output(KVI_OUT_INTERNAL, __tr("Average hops: %d.%d"), avgHops / 100, avgHops % 100);
-	} else outputNoFmt(KVI_OUT_INTERNAL, __tr("Partial LINKS result: no stats available"));
+		output(KVI_OUT_INTERNAL, _i18n_("Far links (7+ hops): %d (%d.%d%)"), farLinks, farProcent / 100, farProcent % 100);
+		output(KVI_OUT_INTERNAL, _i18n_("Broken (unknown) links: %d"), brokenLinks);
+		output(KVI_OUT_INTERNAL, _i18n_("Max links per host: %d [%s]"), maxLinks, szMaxLinks.ptr());
+		output(KVI_OUT_INTERNAL, _i18n_("Total links: %d"), totalHops);
+		output(KVI_OUT_INTERNAL, _i18n_("Maximum hops: %d [%s]"), maxHops, szMaxHop.ptr());
+		output(KVI_OUT_INTERNAL, _i18n_("Average hops: %d.%d"), avgHops / 100, avgHops % 100);
+	} else outputNoFmt(KVI_OUT_INTERNAL, _i18n_("Partial LINKS result: no stats available"));
 	outputNoFmt(KVI_OUT_INTERNAL, "======================");
 
 	while( !m_pLinkList->isEmpty() )
@@ -287,20 +287,20 @@ void KviLinksWindow::hostPopupClicked(int id)
 	KviStr tmp = m_pHostPopup->text(id);
 	if( tmp.hasData() ) {
 		if( !m_pFrm->m_pSocket->sendData(tmp.ptr()) )
-			output(KVI_OUT_ERROR, __tr("Not connected to server"));
+			output(KVI_OUT_ERROR, _i18n_("Not connected to server"));
 	}
 }
 
 void KviLinksWindow::reset()
 {
-	outputNoFmt(KVI_OUT_INTERNAL, __tr("Reset"));
+	outputNoFmt(KVI_OUT_INTERNAL, _i18n_("Reset"));
 	while( !m_pLinkList->isEmpty() )
 		m_pLinkList->removeFirst();
 }
 
 void KviLinksWindow::processLink(const char *msg)
 {
-	output(KVI_OUT_INTERNAL, __tr("Processing link: %s"), msg);
+	output(KVI_OUT_INTERNAL, _i18n_("Processing link: %s"), msg);
 	KviLink *l = new KviLink;
 	msg = kvi_extractToken(l->host,   msg, ' ');
 	msg = kvi_extractToken(l->parent, msg, ' ');
@@ -315,7 +315,7 @@ void KviLinksWindow::processLink(const char *msg)
 		KviStr tmp(aux, msg - aux);
 		l->hops = tmp.toInt();
 	} else {
-		outputNoFmt(KVI_OUT_ERROR, __tr("Broken message syntax: cannot extract hops number, assuming 0"));
+		outputNoFmt(KVI_OUT_ERROR, _i18n_("Broken message syntax: cannot extract hops number, assuming 0"));
 		l->hops = 0;
 	}
 	while( *msg && (*msg == ' ') )
