@@ -24,9 +24,17 @@
 
 #include <signal.h>
 
-#include "kvi_app.h"
 #include "kvi_defines.h"
 
+#ifdef COMPILE_NEED_KDE
+#include <kdeversion.h>
+#if KDE_IS_VERSION(3,2,0)
+#include <kcmdlineargs.h>
+#endif
+#endif
+
+#include "kvi_app.h"
+
 //
 // This here is just a tiny suggestion... A nice (IMHO) way for KVIrc to
 // *at least* save its settings in case it segfaults - this may sometimes happen
@@ -38,7 +46,7 @@ void sigsegv_handler(int);
 #define KVI_ARGS_RETCODE_ERROR 1
 #define KVI_ARGS_RETCODE_STOP  2
 
-int parseArgs(int argc, char **argv, char **configFile, char **server, char **port, bool *createFile)
+int parseArgs(int argc, char **argv, char **configFile, char **sessionFile, char **server, char **port, bool *createFile)
 {
 	if( argc > 1 ) {
 		int idx = 1;
@@ -79,6 +87,13 @@ int parseArgs(int argc, char **argv, char **configFile, char **server, char **po
 				*configFile = argv[idx];
 				*createFile = true;
 				debug("Using file %s as config", argv[idx]);
+			} else if( kvi_strEqualCI("-session", argv[idx]) ) {
+				idx++;
+				if( idx >= argc ) {
+					debug("Option -session requires a session file name");
+					return KVI_ARGS_RETCODE_ERROR;
+				}
+				*sessionFile = argv[idx];
 			} else {
 				if( (*(argv[idx]) != '-') && (!(*port)) ) {
 					// No dash
@@ -104,18 +119,24 @@ int parseArgs(int argc, char **argv, char **configFile, char **server, char **po
 
 int main(int argc, char **argv)
 {
-	char *configFile = 0;
-	char *port       = 0;
-	char *server     = 0;
-	bool createFile  = false;
+	char *configFile  = 0;
+	char *sessionFile = 0;
+	char *port        = 0;
+	char *server      = 0;
+	bool createFile   = false;
 
 	if( signal(SIGSEGV, sigsegv_handler) == SIG_ERR )
 		debug("Error in call to signal() - continuing anyway.");
 
-	int retCode = parseArgs(argc, argv, &configFile, &server, &port, &createFile);
+	int retCode = parseArgs(argc, argv, &configFile, &sessionFile, &server, &port, &createFile);
 	if( retCode != KVI_ARGS_RETCODE_OK )
 		return ((retCode == KVI_ARGS_RETCODE_ERROR) ? (-1) : 0);
 
+#ifdef COMPILE_NEED_KDE
+#if KDE_IS_VERSION(3,2,0)
+	KCmdLineArgs::init(argc, argv, "kvirc", "kvirc", "", VERSION);
+#endif
+#endif
 	g_pApp = new KviApp(argc, argv);
 	g_pApp->m_pCreateConfig = createFile;
 	g_pApp->m_pConfigFile   = configFile;
