@@ -96,7 +96,7 @@ extern KviRawEventManager *g_pRawEventManager;
 KviOptions::KviOptions()
 {
 	g_setSplashScreenProgress(14);
-	g_setSplashScreenText(__tr("Loading options..."));
+	g_setSplashScreenText(_i18n_("Loading options..."));
 
 	for( int i = 0; i < 16; i++ )
 		m_pMircColor[i] = new QColor(defaultMircRgb[i]);
@@ -155,7 +155,7 @@ KviOptions::~KviOptions()
  */
 void KviOptions::load()
 {
-	g_setSplashScreenText(__tr("Loading GUI options..."));
+	g_setSplashScreenText(_i18n_("Loading GUI options..."));
 	loadMircColors();
 	g_setSplashScreenProgress(18);
 	loadViewOptions();
@@ -180,7 +180,7 @@ void KviOptions::load()
 	g_setSplashScreenProgress(52);
 	loadScriptCenterOptions();
 	g_setSplashScreenProgress(54);
-	g_setSplashScreenText(__tr("Loading core options..."));
+	g_setSplashScreenText(_i18n_("Loading core options..."));
 	loadSocketOptions();
 	g_setSplashScreenProgress(56);
 	loadServerOptions();
@@ -197,7 +197,7 @@ void KviOptions::load()
 	g_setSplashScreenProgress(69);
 	loadLoggingOptions();
 	g_setSplashScreenProgress(71);
-	g_setSplashScreenText(__tr("Loading aliases, popups, event handlers..."));
+	g_setSplashScreenText(_i18n_("Loading aliases, popups, event handlers..."));
 	loadAliases();
 	g_setSplashScreenProgress(73);
 	loadPopups();
@@ -1440,7 +1440,7 @@ void KviOptions::loadAliases()
 	KviStr error;
 	if( !g_pAliasManager->load(szTemp.ptr(), error) ) {
 		g_pApp->warningBox(
-			__tr("Error while parsing the aliases database:\n"\
+			_i18n_("Error while parsing the aliases database:\n"\
 			"%s\nSome aliases may not work correctly."),
 			error.ptr()
 		);
@@ -1456,7 +1456,7 @@ void KviOptions::saveAliases()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.alias.conf");
 	if( !g_pAliasManager->save(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save aliases to %s\n"\
+			_i18n_("Unable to save aliases to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1474,7 +1474,7 @@ void KviOptions::loadEvents()
 	KviStr error;
 	if( !g_pEventManager->load(szTemp.ptr(), error) ) {
 		g_pApp->warningBox(
-			__tr("Error while parsing the events database:\n"\
+			_i18n_("Error while parsing the events database:\n"\
 			"%s\nSome event handlers may not work correctly."),
 			error.ptr()
 		);
@@ -1490,7 +1490,7 @@ void KviOptions::saveEvents()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.event.conf");
 	if( !g_pEventManager->save(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save events to %s\n"\
+			_i18n_("Unable to save events to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1508,7 +1508,7 @@ void KviOptions::loadRawEvents()
 	KviStr error;
 	if( !g_pRawEventManager->load(szTemp.ptr(), error) ) {
 		g_pApp->warningBox(
-			__tr("Error while parsing the raw events database:\n"\
+			_i18n_("Error while parsing the raw events database:\n"\
 			"%s\nSome event handlers may not work correctly."),
 			error.ptr()
 		);
@@ -1524,7 +1524,7 @@ void KviOptions::saveRawEvents()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.rawevent.conf");
 	if( !g_pRawEventManager->save(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save raw events to %s\n"\
+			_i18n_("Unable to save raw events to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1538,7 +1538,7 @@ void KviOptions::loadRegUsers()
 		return;
 	KviStr error;
 	if( !m_pRegUsersDb->load(szTemp.ptr(), error) )
-		g_pApp->warningBox(__tr("Error while parsing the registered users database: %s."), error.ptr());
+		g_pApp->warningBox(_i18n_("Error while parsing the registered users database: %s."), error.ptr());
 }
 
 void KviOptions::saveRegUsers()
@@ -1547,7 +1547,7 @@ void KviOptions::saveRegUsers()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.regusersdb.conf");
 	if( !m_pRegUsersDb->save(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save registered users to %s\n"\
+			_i18n_("Unable to save registered users to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1562,7 +1562,7 @@ void KviOptions::loadPlugins()
 		return;
 	KviStr error;
 	if( !g_pPluginManager->load(szTemp.ptr(), error) )
-		g_pApp->warningBox(__tr("Encountered errors while\nparsing the plugins database:\n%s."), error.ptr());
+		g_pApp->warningBox(_i18n_("Encountered errors while\nparsing the plugins database:\n%s."), error.ptr());
 }
 
 void KviOptions::savePlugins()
@@ -1571,7 +1571,7 @@ void KviOptions::savePlugins()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.plugin.conf");
 	if( !g_pPluginManager->save(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save plugins to %s\n"\
+			_i18n_("Unable to save plugins to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1587,7 +1587,7 @@ void KviOptions::loadPopups()
 	KviStr error;
 	if( !KviUserPopupMenu::loadAllPopups(szTemp.ptr(), error) ) {
 		g_pApp->warningBox(
-			__tr("Error while parsing the popups database:\n"\
+			_i18n_("Error while parsing the popups database:\n"\
 			"%s\nSome popups handlers may not work correctly."),
 			error.ptr()
 		);
@@ -1600,7 +1600,7 @@ void KviOptions::savePopups()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.popup.conf");
 	if( !KviUserPopupMenu::saveAllPopups(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save popups to %s\n"\
+			_i18n_("Unable to save popups to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1613,7 +1613,7 @@ void KviOptions::saveToolBar()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.toolbar.conf");
 	if( !KviUserToolBarTemplate::saveToolBarTemplate(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save toolbar to %s\n"\
+			_i18n_("Unable to save toolbar to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
@@ -1628,7 +1628,7 @@ void KviOptions::loadToolBar()
 	KviStr error;
 	if( !KviUserToolBarTemplate::loadToolBarTemplate(szTemp.ptr(), error) ) {
 		g_pApp->warningBox(
-			__tr("Error while parsing the toolbar database:\n"\
+			_i18n_("Error while parsing the toolbar database:\n"\
 			"%s\nSome toolbar handlers may not work correctly."),
 			error.ptr()
 		);
@@ -1643,7 +1643,7 @@ void KviOptions::loadWinProperties()
 	KviStr error;
 	if( !m_pWinPropertiesList->load(szTemp.ptr(), error) ) {
 		g_pApp->warningBox(
-			__tr("Error while parsing the window properties database:\n"\
+			_i18n_("Error while parsing the window properties database:\n"\
 			"%s\nSome windows may loose their settings."),
 			error.ptr()
 		);
@@ -1656,7 +1656,7 @@ void KviOptions::saveWinProperties()
 	g_pApp->getLocalKVIrcDirectory(szTemp, KviApp::Config, "kvi.winproperties.conf");
 	if( !m_pWinPropertiesList->save(szTemp.ptr()) ) {
 		g_pApp->warningBox(
-			__tr("Unable to save the window properties to %s\n"\
+			_i18n_("Unable to save the window properties to %s\n"\
 			"Please check your write permissions."),
 			szTemp.ptr()
 		);
