@@ -101,7 +101,7 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	// Tab, rows, cols
 	QGridLayout *g = new QGridLayout(tab, 7, 3, 10, 4);
 
-	KviLabel *l = new KviLabel(__tr("Network:"), tab);
+	KviLabel *l = new KviLabel(_i18n_("Network:"), tab);
 	g->addWidget(l, 0, 0);
 
 	m_pNetCombo = new KviComboBox(true, tab);
@@ -125,7 +125,7 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	m_pServerList->header()->setClickEnabled(false, -1); // Disable click
 	m_pServerList->header()->setMovingEnabled(false);
 	m_pServerList->setFocusPolicy(StrongFocus);
-	QToolTip::add(m_pServerList, __tr("Double-click to edit"));
+	QToolTip::add(m_pServerList, _i18n_("Double-click to edit"));
 
 	m_pEditor = new KviFieldEditor(m_pServerList->viewport());
 	m_pServerList->setFieldEditor(m_pEditor);
@@ -175,39 +175,39 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	g = new QGridLayout(tab, 10, 1, 10, 4);
 
 	KviStringSelector *ss = new KviStringSelector(tab,
-		__tr("Local host IP address:"), &(g_pOptions->m_szLocalHostIp), true
+		_i18n_("Local host IP address:"), &(g_pOptions->m_szLocalHostIp), true
 	);
 	g->addWidget(ss, 0, 0);
 
 
 	KviBoolSelector *bs = new KviBoolSelector(tab,
-		__tr("Bind IRC sockets to the local host IP address"), &(g_pOptions->m_bBindIrcSocketToSpecificInterface)
+		_i18n_("Bind IRC sockets to the local host IP address"), &(g_pOptions->m_bBindIrcSocketToSpecificInterface)
 	);
 	g->addWidget(bs, 1, 0);
 
 	KviIntegerSelector *is = new KviIntegerSelector(tab,
-		__tr("Connection timeout:"),
+		_i18n_("Connection timeout:"),
 		(void *) &(g_pOptions->m_iSocketTimeout),
 		KviIntegerSelector::Int, 5, 600, 60, true, 100, 0,
-		__tr(" second(s)")
+		_i18n_(" second(s)")
 	);
 	g->addWidget(is, 2, 0);
 
 	bs = new KviBoolSelector(tab,
-		__tr("Automatically reconnect on disconnect"), &(g_pOptions->m_bAutoReconnectOnDisconnect)
+		_i18n_("Automatically reconnect on disconnect"), &(g_pOptions->m_bAutoReconnectOnDisconnect)
 	);
 	g->addWidget(bs, 3, 0);
 
 	bs = new KviBoolSelector(tab,
-		__tr("Close channel and query windows on disconnect"), &(g_pOptions->m_bCloseWindowsOnDisconnect)
+		_i18n_("Close channel and query windows on disconnect"), &(g_pOptions->m_bCloseWindowsOnDisconnect)
 	);
 	g->addWidget(bs, 4, 0);
 
-	bs = new KviBoolSelector(tab, __tr("Rejoin channels on reconnect"), &(g_pOptions->m_bRejoinChannelsOnReconnect));
+	bs = new KviBoolSelector(tab, _i18n_("Rejoin channels on reconnect"), &(g_pOptions->m_bRejoinChannelsOnReconnect));
 	g->addWidget(bs, 5, 0);
 
 	bs = new KviBoolSelector(tab,
-		__tr("Try next server in the network if connect fails"), &(g_pOptions->m_bTryNextServerOnConnectFailed)
+		_i18n_("Try next server in the network if connect fails"), &(g_pOptions->m_bTryNextServerOnConnectFailed)
 	);
 	g->addWidget(bs, 6, 0);
 
@@ -215,7 +215,7 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	r->setFrameStyle(QFrame::Sunken | QFrame::HLine);
 	g->addWidget(r, 7, 0);
 
-	bs = new KviBoolSelector(tab, __tr("Force synchronous DNS calls"), &(g_pOptions->m_bForceSyncDns));
+	bs = new KviBoolSelector(tab, _i18n_("Force synchronous DNS calls"), &(g_pOptions->m_bForceSyncDns));
 	g->addWidget(bs, 8, 0);
 
 	r = new QFrame(tab);
@@ -232,22 +232,22 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	g = new QGridLayout(tab, 7, 2, 10, 4);
 
 	bs = new KviBoolSelector(tab,
-		__tr("Suppress auto-login with nickname and username"), &(g_pOptions->m_bUseTelnetProxy)
+		_i18n_("Suppress auto-login with nickname and username"), &(g_pOptions->m_bUseTelnetProxy)
 	);
 	g->addMultiCellWidget(bs, 0, 0, 0, 1);
 
 	KviBoolSelector *bs1 = new KviBoolSelector(tab,
-		__tr("Use HTTP/1.0 proxy server"), &(g_pOptions->m_bProxyProtoHttp)
+		_i18n_("Use HTTP/1.0 proxy server"), &(g_pOptions->m_bProxyProtoHttp)
 	);
 	g->addMultiCellWidget(bs1, 1, 1, 0, 1);
 
-	KviBoolSelector *bs2 = new KviBoolSelector(tab, __tr("Use SOCKS proxy server"), &(g_pOptions->m_bUseProxy));
+	KviBoolSelector *bs2 = new KviBoolSelector(tab, _i18n_("Use SOCKS proxy server"), &(g_pOptions->m_bUseProxy));
 	g->addMultiCellWidget(bs2, 2, 2, 0, 1);
 	connect(bs2, SIGNAL(toggled(bool)), bs1, SLOT(setDisabled(bool)));
 	connect(bs1, SIGNAL(toggled(bool)), bs2, SLOT(setDisabled(bool)));
 
 	bs = new KviBoolSelector(tab,
-		__tr("Use SOCKS protocol version 5 instead of version 4"),
+		_i18n_("Use SOCKS protocol version 5 instead of version 4"),
 		&(g_pOptions->m_bProxyProtoV5), g_pOptions->m_bUseProxy
 	);
 	connect(bs2, SIGNAL(toggled(bool)), bs, SLOT(setEnabled(bool)));
@@ -266,7 +266,7 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	m_pProxyList->header()->setClickEnabled(false, -1); // Disable click
 	m_pProxyList->header()->setMovingEnabled(false);
 	m_pProxyList->setFocusPolicy(StrongFocus);
-	QToolTip::add(m_pProxyList, __tr("Double-click to edit"));
+	QToolTip::add(m_pProxyList, _i18n_("Double-click to edit"));
 
 	m_pProxyEditor = new KviFieldEditor(m_pProxyList->viewport());
 	m_pProxyList->setFieldEditor(m_pProxyEditor);
@@ -295,10 +295,10 @@ KviServerDialog::KviServerDialog(QWidget *parent)
 	//
 	// Init stuff
 	//
-	setButtonHelpText(__tr("What is &This?"));
+	setButtonHelpText(_i18n_("What is &This?"));
 	connect(this, SIGNAL(helpClicked()), g_pApp, SLOT(slot_whatIsThisRequest()));
-	setButtonOKText(__tr("&OK"));
-	setButtonCancelText(__tr("&Cancel"));
+	setButtonOK();
+	setButtonCancel();
 
 	installEventFilter(this);
 
@@ -416,7 +416,7 @@ void KviServerDialog::newServer()
 	KviIrcServer *srv = new KviIrcServer();
 	srv->addresses.clear();
 	srv->szHost        = "irc.unknown.net";
-	srv->szDescription = __tr("None");
+	srv->szDescription = _i18n_("None");
 	srv->szPort        = "6667";
 	srv->szPassword    = "";
 #ifdef COMPILE_NEED_IPV6
