@@ -125,7 +125,7 @@ void KviServerParser::parseCTCPPrivmsg(KviIrcUser &source, const char *target, c
 			if( !doCTCPFloodEvent(type.ptr(), source, target, pOut, data) )
 				return;
 			pOut->output(KVI_OUT_FLOOD,
-				__tr("CTCP flood detected: ignoring last CTCP request from %s [%s@%s] to %s: %s %s"),
+				_i18n_("CTCP flood detected: ignoring last CTCP request from %s [%s@%s] to %s: %s %s"),
 				source.nick(), source.username(), source.host(), target, type.ptr(), data
 			);
 			return;
@@ -139,7 +139,7 @@ void KviServerParser::parseCTCPPrivmsg(KviIrcUser &source, const char *target, c
 		if( !doCTCPEvent(type.ptr(), source, target, !(g_pOptions->m_bReplyErrmsgOnUnknownCtcp), pOut, data) )
 			return;
 		pOut->output(KVI_OUT_CTCPERROR,
-			__tr("Unrecognized CTCP request from %s [%s@%s] to %s: %s %s"),
+			_i18n_("Unrecognized CTCP request from %s [%s@%s] to %s: %s %s"),
 			source.nick(), source.username(), source.host(), target, type.ptr(), data
 		);
 
@@ -180,8 +180,8 @@ bool KviServerParser::showCTCPRequest(const char *ctcpName, KviIrcUser &source,
 		if( !doCTCPEvent(ctcpName, source, target, bIgnore, m_pConsole) )
 			return false;
 		pOut->output(KVI_OUT_CTCPREQUEST,
-			__tr("CTCP %s request from %s [%s@%s]: %s"),
-			ctcpName, source.nick(), source.username(), source.host(), bIgnore ? __tr("ignored") : __tr("replied"));
+			_i18n_("CTCP %s request from %s [%s@%s]: %s"),
+			ctcpName, source.nick(), source.username(), source.host(), bIgnore ? _i18n_("ignored") : _i18n_("replied"));
 	} else {
 		KviChannel *chan = m_pFrm->findChannel(target);
 		if( chan ) {
@@ -191,16 +191,16 @@ bool KviServerParser::showCTCPRequest(const char *ctcpName, KviIrcUser &source,
 			if( !doCTCPEvent(ctcpName, source, target, bIgnore, chan) )
 				return false;
 			pOut->output(KVI_OUT_CTCPREQUEST,
-				__tr("Channel CTCP %s request from %s [%s@%s]: %s"),
-				ctcpName, source.nick(), source.username(), source.host(), bIgnore ? __tr("ignored") : __tr("replied")
+				_i18n_("Channel CTCP %s request from %s [%s@%s]: %s"),
+				ctcpName, source.nick(), source.username(), source.host(), bIgnore ? _i18n_("ignored") : _i18n_("replied")
 			);
 		} else {
 			// Oops, desync with the server.
 			KviWindow *pOut = g_pOptions->m_bDesyncMsgsToConsole ? ((KviWindow *) m_pConsole) : m_pFrm->activeWindow();
 			pOut->output(KVI_OUT_DESYNC,
-				__tr("Local desync: CTCP %s from %s [%s@%s] to %s: %s"),
+				_i18n_("Local desync: CTCP %s from %s [%s@%s] to %s: %s"),
 				ctcpName, source.nick(), source.username(), source.host(), target,
-				bIgnore ? __tr("ignored") : __tr("replied")
+				bIgnore ? _i18n_("ignored") : _i18n_("replied")
 			);
 		}
 	}
@@ -237,9 +237,9 @@ void KviServerParser::handleCTCPPingRequest(KviIrcUser &source, const char *targ
 		if( !doCTCPEvent("PING", source, target, g_pOptions->m_bIgnoreCtcpPingRequests, m_pConsole, data) )
 			return;
 		pOut->output(KVI_OUT_CTCPREQUEST,
-			__tr("CTCP PING request from %s [%s@%s] (PING %s): %s"),
+			_i18n_("CTCP PING request from %s [%s@%s] (PING %s): %s"),
 			source.nick(), source.username(), source.host(), data,
-			g_pOptions->m_bIgnoreCtcpPingRequests ? __tr("ignored") : __tr("replied")
+			g_pOptions->m_bIgnoreCtcpPingRequests ? _i18n_("ignored") : _i18n_("replied")
 		);
 	} else {
 		KviChannel *chan = m_pFrm->findChannel(target);
@@ -250,17 +250,17 @@ void KviServerParser::handleCTCPPingRequest(KviIrcUser &source, const char *targ
 			if( !doCTCPEvent("PING", source, target, g_pOptions->m_bIgnoreCtcpPingRequests, m_pConsole, data) )
 				return;
 			pOut->output(KVI_OUT_CTCPREQUEST,
-				__tr("Channel CTCP PING request from %s [%s@%s] (PING %s): %s"),
+				_i18n_("Channel CTCP PING request from %s [%s@%s] (PING %s): %s"),
 				source.nick(), source.username(), source.host(), data,
-				g_pOptions->m_bIgnoreCtcpPingRequests ? __tr("ignored") : __tr("replied")
+				g_pOptions->m_bIgnoreCtcpPingRequests ? _i18n_("ignored") : _i18n_("replied")
 			);
 		} else {
 			// Oops, desync with the server.
 			KviWindow *pOut = g_pOptions->m_bDesyncMsgsToConsole ? m_pConsole : m_pFrm->activeWindow();
 			pOut->output(KVI_OUT_DESYNC,
-				__tr("Local desync: CTCP PING from %s [%s@%s] to %s (PING %s): %s"),
+				_i18n_("Local desync: CTCP PING from %s [%s@%s] to %s (PING %s): %s"),
 				source.nick(), source.username(), source.host(), target, data,
-				g_pOptions->m_bIgnoreCtcpPingRequests ? __tr("ignored") : __tr("replied"));
+				g_pOptions->m_bIgnoreCtcpPingRequests ? _i18n_("ignored") : _i18n_("replied"));
 		}
 	}
 	if( !g_pOptions->m_bIgnoreCtcpPingRequests )
@@ -417,20 +417,20 @@ void KviServerParser::handleCTCPDccRequest(KviIrcUser &source, const char *targe
 	// Check for unrecoverable errors
 	KviStr szError;
 	if( dcc->szType.isEmpty() )
-		szError = __tr("The DCC type is empty");
+		szError = _i18n_("The DCC type is empty");
 	if( dcc->szParam.isEmpty() )
-		szError = __tr("The DCC type dependant parameter is empty");
+		szError = _i18n_("The DCC type dependant parameter is empty");
 	if( !isMe(target) )
-		szError = __tr("The DCC target is not me!");
+		szError = _i18n_("The DCC target is not me!");
 	if( dcc->szAddress.isEmpty() || (!dcc->szAddress.isUnsignedNum()) )
-		szError = __tr("The 3rd parameter is not an unsigned number");
+		szError = _i18n_("The 3rd parameter is not an unsigned number");
 	if( dcc->szPort.isEmpty() || (!dcc->szPort.isUnsignedNum()) )
-		szError = __tr("The 4th parameter is not an unsigned number");
+		szError = _i18n_("The 4th parameter is not an unsigned number");
 
 	if( szError.hasData() ) {
 		KviWindow *pOut = g_pOptions->m_bCtcpRequestsToConsole ? m_pConsole : m_pFrm->activeWindow();
 		pOut->output(KVI_OUT_CTCPERROR,
-			__tr("Malformed CTCP DCC request from %s [%s@%s] to %s: [%s]: %s"),
+			_i18n_("Malformed CTCP DCC request from %s [%s@%s] to %s: [%s]: %s"),
 			source.nick(), source.username(), source.host(), target, dcc->szOriginalRequest.ptr(), szError.ptr()
 		);
 		delete dcc;
@@ -476,7 +476,7 @@ void KviServerParser::parseCTCPNotice(KviIrcUser &source, const char *target, co
 	if( !doCTCPReplyEvent(type.ptr(), source, target, pOut, data) )
 		return; // No output
 	pOut->output(KVI_OUT_CTCPERROR,
-		__tr("Unrecognized CTCP reply from %s [%s@%s] to %s: %s %s"),
+		_i18n_("Unrecognized CTCP reply from %s [%s@%s] to %s: %s %s"),
 		source.nick(), source.username(), source.host(), target, type.ptr(), data
 	);
 }
@@ -488,7 +488,7 @@ void KviServerParser::showCTCPReply(const char *ctcpName, KviIrcUser &source, co
 		if( !doCTCPReplyEvent(ctcpName, source, target, m_pConsole, data) )
 			return; // No output
 		pOut->output(KVI_OUT_CTCPREPLY,
-			__tr("CTCP %s reply from %s [%s@%s]: %s"),
+			_i18n_("CTCP %s reply from %s [%s@%s]: %s"),
 			ctcpName, source.nick(), source.username(), source.host(), data
 		);
 	} else {
@@ -497,7 +497,7 @@ void KviServerParser::showCTCPReply(const char *ctcpName, KviIrcUser &source, co
 		if( !doCTCPReplyEvent(ctcpName, source, target, m_pConsole, data) )
 			return; // No output
 		pOut->output(KVI_OUT_CTCPREPLY,
-			__tr("CTCP %s reply from %s [%s@%s] to %s: %s"),
+			_i18n_("CTCP %s reply from %s [%s@%s] to %s: %s"),
 			ctcpName, source.nick(), source.username(), source.host(), target, data
 		);
 	}
@@ -531,11 +531,11 @@ void KviServerParser::handleCTCPPingReply(KviIrcUser &source, const char *target
 	unsigned int uTime = tmp.toUInt(&bOk);
 	KviStr timeDiff;
 	if( !bOk )
-		timeDiff = __tr("Malformed PING reply");
+		timeDiff = _i18n_("Malformed PING reply");
 	else {
 		int iDiff = time(0) - uTime;
 		timeDiff.setNum(iDiff);
-		timeDiff.append(__tr(" seconds"));
+		timeDiff.append(_i18n_(" seconds"));
 	}
 	showCTCPReply("PING", source, target, timeDiff.ptr());
 }
@@ -617,7 +617,7 @@ void KviServerParser::handleCTCPActionReply(KviIrcUser &source, const char *targ
 					return;
 				query = m_pFrm->createQuery(source.nick(), true);
 				query->output(KVI_OUT_INTERNAL,
-					__tr("Private conversation requested by %s [%s@%s]"), source.nick(), source.username(), source.host()
+					_i18n_("Private conversation requested by %s [%s@%s]"), source.nick(), source.username(), source.host()
 				);
 				query->output(KVI_OUT_ACTION,
 					"\r!%s\r%s\r %s", g_pOptions->m_szPrivmsgFormatNickLinkCommand.ptr(), source.nick(), data
@@ -626,7 +626,7 @@ void KviServerParser::handleCTCPActionReply(KviIrcUser &source, const char *targ
 				if( !doActionEvent(source, target, m_pConsole, '0', data) )
 					return;
 				m_pFrm->activeWindow()->output(KVI_OUT_ACTION,
-					__tr("%s!%s@%s %s"), source.nick(), source.username(), source.host(), data
+					_i18n_("%s!%s@%s %s"), source.nick(), source.username(), source.host(), data
 				);
 			}
 		}
@@ -642,7 +642,7 @@ void KviServerParser::handleCTCPActionReply(KviIrcUser &source, const char *targ
 			// Oops, desync with the server.
 			KviWindow *pOut = g_pOptions->m_bDesyncMsgsToConsole ? m_pConsole : m_pFrm->activeWindow();
 			pOut->output(KVI_OUT_DESYNC,
-				__tr("Local desync: CTCP ACTION from %s [%s@%s] to %s: %s"),
+				_i18n_("Local desync: CTCP ACTION from %s [%s@%s] to %s: %s"),
 				source.nick(), source.username(), source.host(), target, data
 			);
 		}
@@ -709,7 +709,7 @@ bool KviServerParser::doMultimediaEvent(
 void KviServerParser::handleCTCPMultimediaReply(KviIrcUser &source, const char *target, const char *data)
 {
 	const char *eventData  = data ? data : "";
-	const char *outputData = data ? data : __tr("[nothing]");
+	const char *outputData = data ? data : _i18n_("[nothing]");
 	if( isMe(target) ) {
 		KviQuery *query = m_pFrm->findQuery(source.nick());
 		if( query ) {
@@ -724,17 +724,17 @@ void KviServerParser::handleCTCPMultimediaReply(KviIrcUser &source, const char *
 					return;
 				query = m_pFrm->createQuery(source.nick(), true);
 				query->output(KVI_OUT_INTERNAL,
-					__tr("Private conversation requested by %s [%s@%s]"), source.nick(), source.username(), source.host()
+					_i18n_("Private conversation requested by %s [%s@%s]"), source.nick(), source.username(), source.host()
 				);
 				query->output(KVI_OUT_MULTIMEDIA,
-					__tr("\r!%s\r%s\r plays %s"),
+					_i18n_("\r!%s\r%s\r plays %s"),
 					g_pOptions->m_szPrivmsgFormatNickLinkCommand.ptr(), source.nick(), outputData
 				);
 			} else {
 				if( !doMultimediaEvent(source, target, m_pConsole, '0', eventData) )
 					return;
 				m_pFrm->activeWindow()->output(KVI_OUT_MULTIMEDIA,
-					__tr("%s!%s@%s plays %s"), source.nick(), source.username(), source.host(), outputData
+					_i18n_("%s!%s@%s plays %s"), source.nick(), source.username(), source.host(), outputData
 				);
 			}
 		}
@@ -750,7 +750,7 @@ void KviServerParser::handleCTCPMultimediaReply(KviIrcUser &source, const char *
 			// Oops, desync with the server.
 			KviWindow *pOut = g_pOptions->m_bDesyncMsgsToConsole ? m_pConsole : m_pFrm->activeWindow();
 			pOut->output(KVI_OUT_DESYNC,
-				__tr("Local desync: CTCP MULTIMEDIA from %s [%s@%s] to %s: %s"),
+				_i18n_("Local desync: CTCP MULTIMEDIA from %s [%s@%s] to %s: %s"),
 				source.nick(), source.username(), source.host(), target, eventData
 			);
 		}
@@ -781,7 +781,7 @@ void KviServerParser::handleCTCPMultimediaReply(KviIrcUser &source, const char *
 				m_pFrm->m_pSocket->sendFmtData("PRIVMSG %s :!%s %s", source.nick(), source.nick(), file.ptr());
 				if( g_pOptions->m_bBeVerbose ) {
 					m_pConsole->output(KVI_OUT_INTERNAL,
-						__tr("Sent PRIVMSG %s: !%s %s"), source.nick(), source.nick(), file.ptr()
+						_i18n_("Sent PRIVMSG %s: !%s %s"), source.nick(), source.nick(), file.ptr()
 					);
 				}
 			}
@@ -801,20 +801,20 @@ void KviServerParser::handleCTCPMultimediaReply(KviIrcUser &source, const char *
 				} else {
 					// Unsafe command, just warn
 					m_pConsole->output(KVI_OUT_ERROR,
-						__tr("CTCP MULTIMEDIA: cannot play file %s: the remote triggering of the commandline "\
+						_i18n_("CTCP MULTIMEDIA: cannot play file %s: the remote triggering of the commandline "\
 						"(%s) is potentially dangerous"), fileWithPath.ptr(), m->commandline.ptr()
 					);
 				}
 			} else {
 				// No commandline at all
 				m_pConsole->output(KVI_OUT_ERROR,
-					__tr("CTCP MULTIMEDIA: cannot play file %s: no commandline specified"), fileWithPath.ptr()
+					_i18n_("CTCP MULTIMEDIA: cannot play file %s: no commandline specified"), fileWithPath.ptr()
 				);
 			}
 		} else {
 			// Cannot play... no appropriate player found
 			m_pConsole->output(KVI_OUT_ERROR,
-				__tr("CTCP MULTIMEDIA: cannot play file %s: no matching MIME type"), fileWithPath.ptr()
+				_i18n_("CTCP MULTIMEDIA: cannot play file %s: no matching MIME type"), fileWithPath.ptr()
 			);
 		}
 	}
