@@ -665,12 +665,12 @@ void KviUserListBox::dragMoveEvent(QDragMoveEvent *e)
 				data->extFlag = 1;
 				KviStr szMask;
 				data->pNode->pUser->mask(szMask);
-				szMask.prepend(__tr("Drop the file to DCC SEND it to "));
+				szMask.prepend(_i18n_("Drop the file to DCC SEND it to "));
 				m_pFrm->m_pStatusBar->tempText(szMask.ptr(), KVI_USERLISTBOX_USERMASK_STATUSBAR_SHOW_TIME);
 			}
 		} else {
 			m_pFrm->m_pStatusBar->tempText(
-				__tr("Drop the file over a nickname to start the DCC SEND"), KVI_USERLISTBOX_USERMASK_STATUSBAR_SHOW_TIME
+				_i18n_("Drop the file over a nickname to start the DCC SEND"), KVI_USERLISTBOX_USERMASK_STATUSBAR_SHOW_TIME
 			);
 		}
 		paintEvent(0);
