@@ -403,9 +403,9 @@ void KviUserParser::parseUserCommand(QString &str, KviWindow *pWnd)
 						return;
 				}
 				if( m_pSocket->sendData(str.ascii(), str.length()) )
-					pWnd->output(KVI_OUT_RAW, __tr("Raw to server: %s"), str.ascii());
+					pWnd->output(KVI_OUT_RAW, _i18n_("Raw to server: %s"), str.ascii());
 				else
-					pWnd->outputNoFmt(KVI_OUT_ERROR, __tr("Cannot send data: not connected to server"));
+					pWnd->outputNoFmt(KVI_OUT_ERROR, _i18n_("Cannot send data: not connected to server"));
 				break;
 			case KVI_WND_TYPE_CHANNEL:
 				if( g_pEventManager->eventEnabled(KviEvent_OnChannelInput) ) {
@@ -417,8 +417,8 @@ void KviUserParser::parseUserCommand(QString &str, KviWindow *pWnd)
 					if( m_pSocket->sendFmtData("PRIVMSG %s :%s", pWnd->caption(), str.ascii()) )
 						m_pFrm->outputPrivmsg(pWnd, KVI_OUT_OWN, pme.ptr(), pmask.ptr(), str.ascii());
 					else
-						pWnd->outputNoFmt(KVI_OUT_ERROR, __tr("Cannot send data: not connected to server"));
-				} else pWnd->outputNoFmt(KVI_OUT_ERROR, __tr("Cannot send data: not on channel"));
+						pWnd->outputNoFmt(KVI_OUT_ERROR, _i18n_("Cannot send data: not connected to server"));
+				} else pWnd->outputNoFmt(KVI_OUT_ERROR, _i18n_("Cannot send data: not on channel"));
 				break;
 			case KVI_WND_TYPE_QUERY:
 				if( g_pEventManager->eventEnabled(KviEvent_OnQueryInput) ) {
@@ -430,7 +430,7 @@ void KviUserParser::parseUserCommand(QString &str, KviWindow *pWnd)
 					m_pFrm->outputPrivmsg(pWnd, KVI_OUT_OWN,
 						m_pFrm->m_global.szCurrentNick.ptr(), m_pFrm->m_global.szCurrentMaskFromServer.ptr(), str.ascii()
 					);
-				} else pWnd->outputNoFmt(KVI_OUT_ERROR, __tr("Cannot send data: not connected to server"));
+				} else pWnd->outputNoFmt(KVI_OUT_ERROR, _i18n_("Cannot send data: not connected to server"));
 				break;
 			case KVI_WND_TYPE_CHAT:
 				if( g_pEventManager->eventEnabled(KviEvent_OnDCCInput) ) {
@@ -442,7 +442,7 @@ void KviUserParser::parseUserCommand(QString &str, KviWindow *pWnd)
 					m_pFrm->outputPrivmsg(pWnd, KVI_OUT_OWN,
 						((KviDccChat *) pWnd)->m_szLocalNick.ptr(), ((KviDccChat *) pWnd)->m_szLocalMask.ptr(), str.ascii()
 					);
-				} else pWnd->output(KVI_OUT_ERROR, __tr("Cannot send data: no connection"));
+				} else pWnd->output(KVI_OUT_ERROR, _i18n_("Cannot send data: no connection"));
 				break;
 			case KVI_WND_TYPE_UWINDOW:
 				if( g_pEventManager->eventEnabled(KviEvent_OnUserWindowInput) ) {
@@ -529,17 +529,17 @@ void KviUserParser::printError(KviCommand *cmd, const char *bufferBegin)
 	getErrorInfo(cmd, bufferBegin, &inf);
 
 	cmd->m_wnd->output(KVI_OUT_ERROR, "======================================================");
-	cmd->m_wnd->output(KVI_OUT_ERROR, __tr("Error in command:   %s"), kvi_getErrorString(cmd->m_err));
+	cmd->m_wnd->output(KVI_OUT_ERROR, _i18n_("Error in command:   %s"), kvi_getErrorString(cmd->m_err));
 	cmd->m_wnd->output(KVI_OUT_ERROR, "======================================================");
-	cmd->m_wnd->output(KVI_OUT_ERROR, __tr("Parsing stopped at:"));
-	cmd->m_wnd->output(KVI_OUT_ERROR, __tr("Line %d:            %s"), inf.iLineNum, inf.szLineStr.ptr());
-	cmd->m_wnd->output(KVI_OUT_ERROR, __tr("Character:          %d"), inf.iCharNum);
-	cmd->m_wnd->output(KVI_OUT_ERROR, __tr("Logical location:   %s"), cmd->m_szErrorLocation.ptr());
+	cmd->m_wnd->output(KVI_OUT_ERROR, _i18n_("Parsing stopped at:"));
+	cmd->m_wnd->output(KVI_OUT_ERROR, _i18n_("Line %d:            %s"), inf.iLineNum, inf.szLineStr.ptr());
+	cmd->m_wnd->output(KVI_OUT_ERROR, _i18n_("Character:          %d"), inf.iCharNum);
+	cmd->m_wnd->output(KVI_OUT_ERROR, _i18n_("Logical location:   %s"), cmd->m_szErrorLocation.ptr());
 	if( cmd->m_szErrorToken.hasData() ) {
 		int idx = cmd->m_szErrorToken.findFirstIdx('\n');
 		KviStr tok((idx == -1) ? cmd->m_szErrorToken : cmd->m_szErrorToken.left(idx));
 		if( tok.hasData() )
-			cmd->m_wnd->output(KVI_OUT_ERROR, __tr("Error detail:       %s"), tok.ptr());
+			cmd->m_wnd->output(KVI_OUT_ERROR, _i18n_("Error detail:       %s"), tok.ptr());
 	}
 }
 
@@ -575,7 +575,7 @@ bool KviUserParser::notConnectedToServer(KviCommand *cmd, const char *inCommand)
 	if( g_pOptions->m_bPedanticParser )
 		return cmd->setError(KVI_ERROR_NotConnectedToServer, inCommand);
 	else
-		return cmd->warning(__tr("%s: not connected to server: ignoring"), inCommand);
+		return cmd->warning(_i18n_("%s: not connected to server: ignoring"), inCommand);
 }
 
 bool KviUserParser::recoverableError(KviCommand *cmd, int error, const char *cmdName, const char *additionalData)
@@ -584,9 +584,9 @@ bool KviUserParser::recoverableError(KviCommand *cmd, int error, const char *cmd
 		return cmd->setError(error, cmdName, additionalData);
 	else {
 		if( additionalData && (*additionalData) )
-			return cmd->warning(__tr("%s: %s (%s): ignoring"), cmdName, kvi_getErrorString(error), additionalData);
+			return cmd->warning(_i18n_("%s: %s (%s): ignoring"), cmdName, kvi_getErrorString(error), additionalData);
 		else
-			return cmd->warning(__tr("%s: %s: ignoring"), cmdName, kvi_getErrorString(error));
+			return cmd->warning(_i18n_("%s: %s: ignoring"), cmdName, kvi_getErrorString(error));
 	}
 }
 
@@ -875,11 +875,11 @@ bool KviUserParser::callEvent(int index, KviWindow *pWnd, const KviStr &params)
 			if( cmd.hasError() ) {
 				printError(&cmd, g_pEventManager->m_szEventBuffer[index].ptr());
 				pWnd->output(KVI_OUT_ERROR,
-					__tr("Caller event:       %s"), g_pEventManager->m_eventDescriptor[index].eventName
+					_i18n_("Caller event:       %s"), g_pEventManager->m_eventDescriptor[index].eventName
 				);
 				if( g_pOptions->m_bAutoDisableBrokenEvents ) {
 					pWnd->output(KVI_OUT_ERROR,
-						__tr("Event handler '%s' is broken: auto-disabling"),
+						_i18n_("Event handler '%s' is broken: auto-disabling"),
 						g_pEventManager->m_eventDescriptor[index].eventName
 					);
 					g_pEventManager->m_bEventEnabled[index] = false;
@@ -927,7 +927,7 @@ bool KviUserParser::callRawEvent(
 		if( cmd.hasError() ) {
 			printError(&cmd, szBuffer.ptr());
 			m_pConsole->output(KVI_OUT_ERROR,
-				__tr("Caller event:       raw %s (source mask: %s)"), szCommand.ptr(), szSourceMask.ptr()
+				_i18n_("Caller event:       raw %s (source mask: %s)"), szCommand.ptr(), szSourceMask.ptr()
 			);
 			if( g_pEventManager->eventEnabled(KviEvent_OnEventError) ) {
 				KviCommandErrorInfo inf;
@@ -954,13 +954,13 @@ bool KviUserParser::triggerObjectEvent(KviScriptObject *o, const char *eventName
 	if( !execCommandBuffer(&cmd) ) {
 		if( cmd.hasError() ) {
 			printError(&cmd, tmp.ptr());
-			m_pConsole->output(KVI_OUT_ERROR, __tr("Caller event:       %s"), eventName);
-			m_pConsole->output(KVI_OUT_ERROR, __tr("Caller object:      type(%s) name(%s) id(%s)"),
+			m_pConsole->output(KVI_OUT_ERROR, _i18n_("Caller event:       %s"), eventName);
+			m_pConsole->output(KVI_OUT_ERROR, _i18n_("Caller object:      type(%s) name(%s) id(%s)"),
 				o->getClass(), o->getName(), o->id()
 			);
 			if( g_pOptions->m_bAutoDisableBrokenEvents ) {
 				m_pConsole->output(KVI_OUT_ERROR,
-					__tr("Event handler '%s' for this object is broken: auto-removing"), eventName
+					_i18n_("Event handler '%s' for this object is broken: auto-removing"), eventName
 				);
 				o->removeEventHandler(eventName);
 			}
@@ -996,8 +996,8 @@ bool KviUserParser::callObjectFunction(
 	if( !bRet ) {
 		if( cmd.hasError() ) {
 			printError(&cmd, tmp.ptr());
-			m_pConsole->output(KVI_OUT_ERROR, __tr("Caller function:    %s"), fncName);
-			m_pConsole->output(KVI_OUT_ERROR, __tr("Caller object:      type(%s) name(%s) id(%s)"),
+			m_pConsole->output(KVI_OUT_ERROR, _i18n_("Caller function:    %s"), fncName);
+			m_pConsole->output(KVI_OUT_ERROR, _i18n_("Caller object:      type(%s) name(%s) id(%s)"),
 				o->getClass(), o->getName(), o->id()
 			);
 			return false;
@@ -1025,7 +1025,7 @@ bool KviUserParser::extractSingleSwitch(KviCommand *cmd)
 
 	// Now a LETTER is required
 	if( (!(*(cmd->m_ptr))) || (!isalpha(*(cmd->m_ptr))) ) {
-		cmd->setError(KVI_ERROR_InvalidOption, __tr("SWITCH PARSING AFTER '-' DELIMITER"), cmd->m_ptr);
+		cmd->setError(KVI_ERROR_InvalidOption, _i18n_("SWITCH PARSING AFTER '-' DELIMITER"), cmd->m_ptr);
 		return false;
 	}
 
@@ -1071,7 +1071,7 @@ bool KviUserParser::extractSingleSwitch(KviCommand *cmd)
 				case '\0': // End of command buffer; append the last block to the buffer and return
 					if( bInString ) {
 						// Unescaped newline or end of data
-						cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("SWITCH PARSING: PARAMETER EXTRACTION"));
+						cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("SWITCH PARSING: PARAMETER EXTRACTION"));
 						delete sw;
 						return false;
 					} // else: it is the end of the command
@@ -1109,7 +1109,7 @@ bool KviUserParser::extractSingleSwitch(KviCommand *cmd)
 					switch( *aux_ptr ) {
 						case '\0':
 							if( bInString ) {
-								cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("SWITCH PARSING: PARAMETER EXTRACTION"));
+								cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("SWITCH PARSING: PARAMETER EXTRACTION"));
 								delete sw;
 								return false;
 							}
@@ -1212,7 +1212,7 @@ bool KviUserParser::processVariable(KviCommand *cmd, KviStr &buffer)
 			cmd->setScopeObject(scObj);
 			// OK... got the key
 			if( szKey.isEmpty() )
-				return cmd->setError(KVI_ERROR_MissingDictionaryKey, __tr("VARIABLE EVALUATION"), szVariable.ptr());
+				return cmd->setError(KVI_ERROR_MissingDictionaryKey, _i18n_("VARIABLE EVALUATION"), szVariable.ptr());
 			varVal = cache->findDictVariable(szVariable.ptr(), szKey.ptr());
 		} else {
 			varVal = cache->find(szVariable.ptr());
@@ -1227,16 +1227,16 @@ bool KviUserParser::processVariable(KviCommand *cmd, KviStr &buffer)
 						if( o )
 							return processObjectScopeRValue(o, cmd, buffer);
 						else
-							return cmd->setError(KVI_ERROR_ObjectNotFound, __tr("OBJECT OPERATOR -> (RVALUE)"), varVal);
+							return cmd->setError(KVI_ERROR_ObjectNotFound, _i18n_("OBJECT OPERATOR -> (RVALUE)"), varVal);
 					} else {
 						return cmd->setError(KVI_ERROR_ObjectNotFound,
-							__tr("OBJECT_OPERATOR -> (RVALUE)"),
-							__tr("The variable contained no object id")
+							_i18n_("OBJECT_OPERATOR -> (RVALUE)"),
+							_i18n_("The variable contained no object id")
 						);
 					}
 				} else {
 					return cmd->setError(KVI_ERROR_VariableOrIdentifierExpected,
-						__tr("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr
+						_i18n_("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr
 					);
 				}
 			}
@@ -1284,9 +1284,9 @@ bool KviUserParser::processVariableKey(KviCommand *cmd, KviStr &buffer)
 			case '\0': // Fall-through
 			case '\n': // End of the string ('\n' is not escaped); fail here
 				if( inString )
-					cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("DICTIONARY KEY"));
+					cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("DICTIONARY KEY"));
 				else
-					cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, __tr("DICTIONARY KEY"));
+					cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, _i18n_("DICTIONARY KEY"));
 				return false;
 				break;
 			case ' ':  // Fall-through
@@ -1337,9 +1337,9 @@ bool KviUserParser::processVariableKey(KviCommand *cmd, KviStr &buffer)
 				switch( *aux_ptr ) {
 					case '\0':
 						if( inString )
-							cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("DICTIONARY KEY"));
+							cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("DICTIONARY KEY"));
 						else
-							cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, __tr("DICTIONARY KEY"));
+							cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, _i18n_("DICTIONARY KEY"));
 						return false;
 						break;
 					case '\n':  // Escaped newline
@@ -1424,14 +1424,14 @@ bool KviUserParser::processIdentifier(KviCommand *cmd, KviStr &buffer)
 			if( !skipCommand(cmd) )
 				return false;
 			KviStr tmp(aux, cmd->m_ptr);
-			KviCommand cmd(tmp.ptr(), cmd->m_wnd);
-			if( !execCommandBuffer(&cmd) ) {
-				if( cmd.hasError() ) {
-					printError(&cmd, tmp.ptr());
+			KviCommand _cmd(tmp.ptr(), cmd->m_wnd);
+			if( !execCommandBuffer(&_cmd) ) {
+				if( _cmd.hasError() ) {
+					printError(&_cmd, tmp.ptr());
 					return false; // We could do better?
 				}
 			}
-			tmpBuffer.append(cmd.m_retBuffer);
+			tmpBuffer.append(_cmd.m_retBuffer);
 		} else {
 			// Normal identifier
 			if( cmd->scopeObject() ) {
@@ -1489,10 +1489,10 @@ bool KviUserParser::processIdentifier(KviCommand *cmd, KviStr &buffer)
 					if( retVal != KVI_ERROR_Success ) {
 						KviStr er;
 						if( classOverride.hasData() )
-							er.sprintf(__tr("function name: %s class override: %s"), ident.ptr(), classOverride.ptr());
+							er.sprintf(_i18n_("function name: %s class override: %s"), ident.ptr(), classOverride.ptr());
 						else
-							er.sprintf(__tr("function name: %s"), ident.ptr());
-						return cmd->setError(retVal, __tr("OBJECT FUNCTION CALL"), er.ptr());
+							er.sprintf(_i18n_("function name: %s"), ident.ptr());
+						return cmd->setError(retVal, _i18n_("OBJECT FUNCTION CALL"), er.ptr());
 					}
 				} else {
 					// Not a scope object
@@ -1530,7 +1530,7 @@ bool KviUserParser::processIdentifier(KviCommand *cmd, KviStr &buffer)
 #endif
 						// Cannot recover without parsing the function paramenters.
 						if( !bDone )
-							return cmd->setError(KVI_ERROR_UnknownFunction, __tr("FUNCTION"), ident.ptr());
+							return cmd->setError(KVI_ERROR_UnknownFunction, _i18n_("FUNCTION"), ident.ptr());
 					} else {
 						ident.toUpper();
 						// Evaluate it...
@@ -1566,9 +1566,9 @@ bool KviUserParser::processIdentifier(KviCommand *cmd, KviStr &buffer)
 						// Can recover from this
 						if( !bDone ) {
 							if( g_pOptions->m_bPedanticParser )
-								return cmd->setError(KVI_ERROR_UnknownIdentifier, __tr("IDENTIFIER"), ident.ptr());
+								return cmd->setError(KVI_ERROR_UnknownIdentifier, _i18n_("IDENTIFIER"), ident.ptr());
 							else
-								return cmd->warning(__tr("IDENTIFIER: unknown identifier (%s): ignoring"), ident.ptr());
+								return cmd->warning(_i18n_("IDENTIFIER: unknown identifier (%s): ignoring"), ident.ptr());
 						}
 					}
 				}
@@ -1587,17 +1587,17 @@ bool KviUserParser::processIdentifier(KviCommand *cmd, KviStr &buffer)
 							return processObjectScopeRValue(o, cmd, buffer);
 						else {
 							return cmd->setError(KVI_ERROR_ObjectNotFound,
-								__tr("OBJECT OPERATOR -> (RVALUE)"), tmpBuffer.ptr()
+								_i18n_("OBJECT OPERATOR -> (RVALUE)"), tmpBuffer.ptr()
 							);
 						}
 					} else {
 						return cmd->setError(KVI_ERROR_ObjectNotFound,
-							__tr("OBJECT_OPERATOR -> (RVALUE)"), __tr("The function/identifier call returned no object id")
+							_i18n_("OBJECT_OPERATOR -> (RVALUE)"), _i18n_("The function/identifier call returned no object id")
 						);
 					}
 				} else {
 					return cmd->setError(KVI_ERROR_VariableOrIdentifierExpected,
-						__tr("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr
+						_i18n_("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr
 					);
 				}
 			}
@@ -1652,7 +1652,7 @@ bool KviUserParser::processCmdSingleToken(KviCommand *cmd)
 			case '\0': // End of command buffer; append the last block to the buffer and return
 				if( bInString ) {
 					// Unescaped newline or end of data
-					cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("COMMAND-PARAMS"));
+					cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("COMMAND-PARAMS"));
 					return false;
 				} // else: it is the end of the command
 				cmd->m_buffer.append(cmd->m_ptr, aux_ptr - cmd->m_ptr);
@@ -1684,7 +1684,7 @@ bool KviUserParser::processCmdSingleToken(KviCommand *cmd)
 				switch( *aux_ptr ) {
 					case '\0':
 						if( bInString ) {
-							cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("COMMAND-PARAMS"));
+							cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("COMMAND-PARAMS"));
 							return false;
 						}
 						return true;
@@ -1733,7 +1733,7 @@ bool KviUserParser::processCmdFinalPart(KviCommand *cmd)
 			case '\n': // End of command buffer; append the last block to the buffer and return
 				if( bInString ) {
 					// Oops; end of buffer while looking for matching '"'
-					cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("COMMAND-PARAMS"));
+					cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("COMMAND-PARAMS"));
 					return false;
 				}
 				cmd->m_buffer.append(cmd->m_ptr, aux_ptr - cmd->m_ptr);
@@ -1789,7 +1789,7 @@ bool KviUserParser::processCmdFinalPart(KviCommand *cmd)
 				switch( *aux_ptr ) {
 					case '\0':
 						if( bInString ) {
-							cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("COMMAND-PARAMS"));
+							cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("COMMAND-PARAMS"));
 							return false;
 						} else return true;
 						break; // Escaped nothing
@@ -1834,7 +1834,7 @@ bool KviUserParser::processCmdFinalPartNoIdent(KviCommand *cmd)
 			case '\n': // End of command buffer; append the last block to the buffer and return
 				if( bInString ) {
 					// Oops; end of buffer while looking for matching '"'
-					cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("COMMAND-PARAMS"));
+					cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("COMMAND-PARAMS"));
 					return false;
 				}
 				cmd->m_buffer.append(cmd->m_ptr, aux_ptr - cmd->m_ptr);
@@ -1876,7 +1876,7 @@ bool KviUserParser::processCmdFinalPartNoIdent(KviCommand *cmd)
 				switch( *aux_ptr ) {
 					case '\0':
 						if( bInString ) {
-							cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("COMMAND-PARAMS"));
+							cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("COMMAND-PARAMS"));
 							return false;
 						} else return true;
 						break; // Escaped nothing...
@@ -1985,9 +1985,9 @@ bool KviUserParser::processFncSingleParamInternal(KviCommand *cmd, KviStr &buffe
 			case '\0': // Fall-through
 			case '\n': // End of the string ('\n' is not escaped); fail here
 				if( inString )
-					cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("FUNCTION-PARAMS"));
+					cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("FUNCTION-PARAMS"));
 				else
-					cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, __tr("FUNCTION-PARAMS"));
+					cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, _i18n_("FUNCTION-PARAMS"));
 				return false;
 				break;
 			case ' ' : // Fall-through
@@ -2053,9 +2053,9 @@ bool KviUserParser::processFncSingleParamInternal(KviCommand *cmd, KviStr &buffe
 				switch( *aux_ptr ) {
 					case '\0':
 						if( inString )
-							cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("FUNCTION-PARAMS"));
+							cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("FUNCTION-PARAMS"));
 						else
-							cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, __tr("FUNCTION-PARAMS"));
+							cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, _i18n_("FUNCTION-PARAMS"));
 						return false;
 						break;
 					case '\n': // Escaped newline
@@ -2332,7 +2332,7 @@ bool KviUserParser::skipIdentifier(KviCommand *cmd)
 					return skipObjectScopeRValue(cmd);
 				else {
 					return cmd->setError(KVI_ERROR_VariableOrIdentifierExpected,
-						__tr("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr
+						_i18n_("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr
 					);
 				}
 			}
@@ -2382,7 +2382,7 @@ bool KviUserParser::skipVariable(KviCommand *cmd)
 			if( (*(cmd->m_ptr) == '%') || (*(cmd->m_ptr) == '$') )
 				return skipObjectScopeRValue(cmd);
 			else
-				cmd->setError(KVI_ERROR_VariableOrIdentifierExpected, __tr("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr);
+				cmd->setError(KVI_ERROR_VariableOrIdentifierExpected, _i18n_("OBJECT OPERATOR -> (RVALUE)"), cmd->m_ptr);
 		}
 	}
 	return true;
@@ -2406,9 +2406,9 @@ bool KviUserParser::skipVariableKey(KviCommand *cmd)
 			case '\0': // Fall-through
 			case '\n': // End of the string ('\n' is not escaped); fail here
 				if( inString )
-					cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("DICTIONARY KEY"));
+					cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("DICTIONARY KEY"));
 				else
-					cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, __tr("DICTIONARY KEY"));
+					cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, _i18n_("DICTIONARY KEY"));
 				return false;
 				break;
 			case '"':
@@ -2433,9 +2433,9 @@ bool KviUserParser::skipVariableKey(KviCommand *cmd)
 				switch( *(cmd->m_ptr) ) {
 					case '\0':
 						if( inString )
-							cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("DICTIONARY KEY"));
+							cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("DICTIONARY KEY"));
 						else
-							cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, __tr("DICTIONARY KEY"));
+							cmd->setError(KVI_ERROR_UnexpectedEndOfCommand, _i18n_("DICTIONARY KEY"));
 						return false;
 						break;
 					case '\n':  // Escaped newline
@@ -2471,7 +2471,7 @@ bool KviUserParser::skipSingleSwitch(KviCommand *cmd)
 
 	// Now a LETTER is required
 	if( (!(*(cmd->m_ptr))) || (!isalpha(*(cmd->m_ptr))) ) {
-		cmd->setError(KVI_ERROR_InvalidOption, __tr("SWITCH PARSING AFTER '-' DELIMITER"), cmd->m_ptr);
+		cmd->setError(KVI_ERROR_InvalidOption, _i18n_("SWITCH PARSING AFTER '-' DELIMITER"), cmd->m_ptr);
 		return false;
 	}
 	++(cmd->m_ptr); // Skip the switch letter
@@ -2509,7 +2509,7 @@ bool KviUserParser::skipSingleSwitch(KviCommand *cmd)
 				case '\0': // End of command buffer; append the last block to the buffer and return
 					if( bInString ) {
 						// Unescaped newline or end of data
-						return cmd->setError(KVI_ERROR_UnexpectedEndInString, __tr("SWITCH PARSING: PARAMETER EXTRACTION"));
+						return cmd->setError(KVI_ERROR_UnexpectedEndInString, _i18n_("SWITCH PARSING: PARAMETER EXTRACTION"));
 					} // else: it is the end of the command
 					cmd->m_ptr = aux_ptr;
 					return true;
@@ -2536,7 +2536,7 @@ bool KviUserParser::skipSingleSwitch(KviCommand *cmd)
 						case '\0':
 							if( bInString ) {
 								return cmd->setError(KVI_ERROR_UnexpectedEndInString,
-									__tr("SWITCH PARSING: PARAMETER EXTRACTION")
+									_i18n_("SWITCH PARSING: PARAMETER EXTRACTION")
 								);
 							}
 							return true;
