@@ -71,7 +71,7 @@ public:
 	KviFrame *frame() const;
 protected:
 	KviFrame         *m_pFrm;
-	KviStr            m_szCaption;
+	QString           m_szCaption;
 	int               m_type;
 	bool              m_bJustGotFocused;
 	KviTaskBarButton *m_pTaskBarButton;
@@ -252,8 +252,8 @@ protected:
 
 inline int          KviWindow::type()        { return m_type; }
 inline bool         KviWindow::isAttached()  { return (parent() != 0); }
-inline const char  *KviWindow::caption()     { return m_szCaption.ptr(); }
-inline const char  *KviWindow::target()      { return m_szCaption.ptr(); }
+inline const char  *KviWindow::caption()     { return m_szCaption.latin1(); }
+inline const char  *KviWindow::target()      { return m_szCaption.latin1(); }
 inline KviMdiChild *KviWindow::mdiParent()   { return (KviMdiChild *) parent(); }
 
 #endif // _KVI_WINDOW_H_INCLUDED_
