@@ -53,26 +53,26 @@ KviWMDockWidget::KviWMDockWidget()
 	connect(m_pSessionsPopup, SIGNAL(aboutToShow()), this, SLOT(fillSessionsPopup()));
 
 	KPopupMenu *m_pConfigurePopup = new KPopupMenu(this, "configure_popup");
-	m_pConfigurePopup->setCaption(__tr("Configure"));
-	m_pConfigurePopup->insertItem(__tr("&User Configuration..."),     g_pApp, SLOT(slot_doUserOptionsDialog()));
-	m_pConfigurePopup->insertItem(__tr("Servers && Proxy &Hosts..."), g_pApp, SLOT(slot_doServerOptionsDialog()));
-	m_pConfigurePopup->insertItem(__tr("&General Options..."),        g_pApp, SLOT(slot_generalOptionsDialog()));
-	m_pConfigurePopup->insertItem(__tr("&Registered Users..."),       g_pApp, SLOT(slot_doRegUsersDialog()));
+	m_pConfigurePopup->setCaption(_i18n_("Configure"));
+	m_pConfigurePopup->insertItem(_i18n_("&User Configuration..."),     g_pApp, SLOT(slot_doUserOptionsDialog()));
+	m_pConfigurePopup->insertItem(_i18n_("Servers && Proxy &Hosts..."), g_pApp, SLOT(slot_doServerOptionsDialog()));
+	m_pConfigurePopup->insertItem(_i18n_("&General Options..."),        g_pApp, SLOT(slot_generalOptionsDialog()));
+	m_pConfigurePopup->insertItem(_i18n_("&Registered Users..."),       g_pApp, SLOT(slot_doRegUsersDialog()));
 
 	m_pContextPopup = new KPopupMenu(this, "dock_popup");
-	m_pContextPopup->setCaption(__tr("Context"));
+	m_pContextPopup->setCaption(_i18n_("Context"));
 	connect(m_pContextPopup, SIGNAL(aboutToShow()), this, SLOT(fillContextPopup()));
 	m_pContextPopup->insertTitle(*g_pixViewOut[KVI_OUT_KVIRC], "KVIrc");
-	m_iFramesMinimize = m_pContextPopup->insertItem(__tr("&Minimize All"), this, SLOT(slot_hideAllFrames()));
-	m_iFramesRestore = m_pContextPopup->insertItem(__tr("&Restore All"),  this, SLOT(slot_showAllFrames()));
-	m_pContextPopup->insertItem(__tr("&Lock..."), this,  SLOT(slot_toggleLock()));
-	m_pContextPopup->insertItem(__tr("&Undock"), g_pApp, SLOT(slot_destroyWMDockWidget()));
+	m_iFramesMinimize = m_pContextPopup->insertItem(_i18n_("&Minimize All"), this, SLOT(slot_hideAllFrames()));
+	m_iFramesRestore = m_pContextPopup->insertItem(_i18n_("&Restore All"),  this, SLOT(slot_showAllFrames()));
+	m_pContextPopup->insertItem(_i18n_("&Lock..."), this,  SLOT(slot_toggleLock()));
+	m_pContextPopup->insertItem(_i18n_("&Undock"), g_pApp, SLOT(slot_destroyWMDockWidget()));
 	m_pContextPopup->insertSeparator();
-	m_pContextPopup->insertItem(__tr("&New Session"), g_pApp, SLOT(createNewFrame()));
-	m_pContextPopup->insertItem(__tr("&Sessions"), m_pSessionsPopup);
-	m_pContextPopup->insertItem(__tr("&Configure"), m_pConfigurePopup);
+	m_pContextPopup->insertItem(_i18n_("&New Session"), g_pApp, SLOT(createNewFrame()));
+	m_pContextPopup->insertItem(_i18n_("&Sessions"), m_pSessionsPopup);
+	m_pContextPopup->insertItem(_i18n_("&Configure"), m_pConfigurePopup);
 	m_pContextPopup->insertSeparator();
-	m_pContextPopup->insertItem(__tr("&Quit"), g_pApp, SLOT(slot_safeQuit()));
+	m_pContextPopup->insertItem(_i18n_("&Quit"), g_pApp, SLOT(slot_safeQuit()));
 
 	m_pNormalIcon    = new QPixmap(KviIconLoader::loadIcon("dock_normal.png"));
 	m_pHighlightIcon = new QPixmap(KviIconLoader::loadIcon("dock_highlight.png"));
@@ -94,7 +94,7 @@ KviWMDockWidget::~KviWMDockWidget()
 void KviWMDockWidget::fillSessionsPopup()
 {
 	m_pSessionsPopup->clear();
-	m_pSessionsPopup->setCaption(__tr("Sessions"));
+	m_pSessionsPopup->setCaption(_i18n_("Sessions"));
 	int i = 0;
 	for( KviFrame *pFrm = g_pApp->m_pFrameList->first(); pFrm; pFrm = g_pApp->m_pFrameList->next() ) {
 		KviStr szItem;
@@ -149,9 +149,9 @@ void KviWMDockWidget::slot_toggleLock()
 	QCString password;
 	int bOk = QDialog::Rejected;
 	if( m_bLocked )
-		bOk = KviPasswordDialog::getPassword(password, __tr("Enter lock password to unlock KVIrc:"));
+		bOk = KviPasswordDialog::getPassword(password, _i18n_("Enter lock password to unlock KVIrc:"));
 	else
-		bOk = KviPasswordDialog::getNewPassword(password, __tr("Set lock password to lock KVIrc:"));
+		bOk = KviPasswordDialog::getNewPassword(password, _i18n_("Set lock password to lock KVIrc:"));
 	if( (bOk == QDialog::Accepted) && !password.isEmpty() ) {
 		register unsigned long a = 0, b = 0, c = 0, d = 0, sum = 0, delta = 0x9E3779B9;
 		int n = 32;
@@ -177,8 +177,8 @@ void KviWMDockWidget::slot_toggleLock()
 				m_bLocked = false;
 			else {
 				KviMessageBox::error(
-					__tr("Password incorrect"),
-					__tr("KVIrc Lock"),
+					_i18n_("Password incorrect"),
+					_i18n_("KVIrc Lock"),
 					this
 				);
 			}
