@@ -514,7 +514,7 @@ void KviScriptObject::addChild(KviScriptObject *o)
 void KviScriptObject::dump(KviWindow *wnd, const char *margin)
 {
 	KviStr tmp(KviStr::Format,
-		__tr("%s%cObject %s, class %s, name %s"), margin ? margin : "", KVI_TEXT_BOLD, id(), getClass(), getName()
+		_i18n_("%s%cObject %s, class %s, name %s"), margin ? margin : "", KVI_TEXT_BOLD, id(), getClass(), getName()
 	);
 	wnd->output(KVI_OUT_KVIRC, tmp.ptr());
 	for( KviScriptObject *o = m_pChildList->first(); o; o = m_pChildList->next() ) {
