@@ -43,7 +43,7 @@
 // TODO: Font properties
 // TODO: QFont & QPixmap?
 // TODO: OnGenericEvent
-// TODO: Settable properties of the KVIrc windows
+// TODO: Setable properties of the KVIrc windows
 
 /*
 	@class: widget
@@ -483,22 +483,22 @@ int KviScriptWidget::builtinFunction_LISTQTPROPERTIES(QPtrList<KviStr> *params,
 {
 	KviWindow *w = controller()->mainFrame()->activeWindow();
 	w->output(KVI_OUT_INTERNAL,
-		__tr("%cListing Qt Properties for widget object %s (%s)"), KVI_TEXT_BOLD, getName(), id()
+		_i18n_("%cListing Qt Properties for widget object %s (%s)"), KVI_TEXT_BOLD, getName(), id()
 	);
 
 	QMetaObject *o = m_pWidget->metaObject();
 	do {
-		w->output(KVI_OUT_INTERNAL, __tr("Properties class: %c%s%c"), KVI_TEXT_BOLD, o->className(), KVI_TEXT_BOLD);
+		w->output(KVI_OUT_INTERNAL, _i18n_("Properties class: %c%s%c"), KVI_TEXT_BOLD, o->className(), KVI_TEXT_BOLD);
 		QStrList l = o->propertyNames(false);
 		int idx = 0;
 		for( char *c = l.first(); c; c = l.next() ) {
 			const QMetaProperty *p = o->property(idx);
 			if( p ) {
 				KviStr tmp(KviStr::Format,
-					__tr("Property: %c%s%c, type: %s"), KVI_TEXT_BOLD, p->name(), KVI_TEXT_BOLD, p->type()
+					_i18n_("Property: %c%s%c, type: %s"), KVI_TEXT_BOLD, p->name(), KVI_TEXT_BOLD, p->type()
 				);
 				if( p->isEnumType() ) {
-					tmp.append(__tr(", enum ("));
+					tmp.append(_i18n_(", enum ("));
 					QStrList le = p->enumKeys();
 					int i = 0;
 					for( char *c2 = le.first(); c2; c2 = le.next() ) {
@@ -511,9 +511,9 @@ int KviScriptWidget::builtinFunction_LISTQTPROPERTIES(QPtrList<KviStr> *params,
 					tmp.append(')');
 				}
 				if( p->isSetType() )
-					tmp.append(__tr(", set"));
+					tmp.append(_i18n_(", set"));
 				if( p->writable() )
-					tmp.append(__tr(", writeable"));
+					tmp.append(_i18n_(", writeable"));
 				w->output(KVI_OUT_INTERNAL, tmp.ptr());
 			} else debug("Oops... no such property: %s", c);
 			idx++;
