@@ -85,7 +85,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	KviLabel *l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	KviLabel *l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Welcome to the KVIrc Script Wizard.\n"\
 		"To begin exporting your script, enter a name and directory for\n"\
 		"the script.\n"\
@@ -104,39 +104,39 @@ KviScriptWizard::KviScriptWizard()
 	l->setAlignment(AlignTop | AlignLeft);
 	g->addMultiCellWidget(l, 0, 0, 1, 2);
 
-	l = new KviLabel(__tr("Name:"), m_pPage1);
+	l = new KviLabel(_i18n_("Name:"), m_pPage1);
 	g->addWidget(l, 1, 1);
 
 	m_pNameEdit = new KviLineEdit(m_pPage1);
-	m_pNameEdit->setText(__tr("My Script"));
+	m_pNameEdit->setText(_i18n_("My Script"));
 	connect(m_pNameEdit, SIGNAL(textChanged(const QString &)), this, SLOT(page1TextChanged(const QString &)));
 	g->addWidget(m_pNameEdit, 1, 2);
 
-	l = new KviLabel(__tr("Version:"), m_pPage1);
+	l = new KviLabel(_i18n_("Version:"), m_pPage1);
 	g->addWidget(l, 2, 1);
 
 	m_pVersionEdit = new KviLineEdit(m_pPage1);
-	m_pVersionEdit->setText(__tr("1.0.0"));
+	m_pVersionEdit->setText(_i18n_("1.0.0"));
 	connect(m_pVersionEdit, SIGNAL(textChanged(const QString &)), this, SLOT(page1TextChanged(const QString &)));
 	g->addWidget(m_pVersionEdit, 2, 2);
 
 	KviStr szPath;
 	g_pApp->getLocalKVIrcDirectory(szPath, KviApp::Scripts);
-	szPath.prepend(__tr("Script directory: "));
+	szPath.prepend(_i18n_("Script directory: "));
 	l = new KviLabel(szPath.ptr(), m_pPage1);
 	g->addMultiCellWidget(l, 3, 3, 1, 2);
 
-	l = new KviLabel(__tr("Subdirectory:"), m_pPage1);
+	l = new KviLabel(_i18n_("Subdirectory:"), m_pPage1);
 	g->addWidget(l, 4, 1);
 
 	m_pSubdirEdit = new KviLineEdit(m_pPage1);
-	m_pSubdirEdit->setText(__tr("MyScript-1.0.0"));
+	m_pSubdirEdit->setText(_i18n_("MyScript-1.0.0"));
 	connect(m_pSubdirEdit, SIGNAL(textChanged(const QString &)), this, SLOT(page1TextChanged(const QString &)));
 	g->addWidget(m_pSubdirEdit, 4, 2);
 
 	g->setRowStretch(0, 1);
 
-	addPage(m_pPage1, _CHAR_2_QSTRING(__tr("Step 1: Script Basics")));
+	addPage(m_pPage1, _CHAR_2_QSTRING(_i18n_("Step 1: Script Basics")));
 /*
 	@quickhelp: QWidget_ScriptWizardPage2
 	@widget: Script wizard page 2
@@ -160,7 +160,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Now, you can enter some descriptive information about your\n"\
 		"script.\n"\
 		"This section is optional, but it never hurts to have a good\n"\
@@ -172,28 +172,28 @@ KviScriptWizard::KviScriptWizard()
 	l->setAlignment(AlignTop | AlignLeft);
 	g->addWidget(l, 0, 1);
 
-	l = new KviLabel(__tr("Author:"), m_pPage2);
+	l = new KviLabel(_i18n_("Author:"), m_pPage2);
 	g->addWidget(l, 1, 1);
 
 	m_pAuthorEdit = new KviLineEdit(m_pPage2);
 	g->addWidget(m_pAuthorEdit, 2, 1);
 
-	l = new KviLabel(__tr("Email:"), m_pPage2);
+	l = new KviLabel(_i18n_("Email:"), m_pPage2);
 	g->addWidget(l, 3, 1);
 
 	m_pEMailEdit = new KviLineEdit(m_pPage2);
 	g->addWidget(m_pEMailEdit, 4, 1);
 
-	l = new KviLabel(__tr("Description:"), m_pPage2);
+	l = new KviLabel(_i18n_("Description:"), m_pPage2);
 	g->addWidget(l, 5, 1);
 
 	m_pDescriptionEdit = new QTextEdit(m_pPage2);
-	m_pDescriptionEdit->setText(__tr("My script is simply great!"));
+	m_pDescriptionEdit->setText(_i18n_("My script is simply great!"));
 	g->addWidget(m_pDescriptionEdit, 6, 1);
 
 	g->setRowStretch(6, 1);
 
-	addPage(m_pPage2, _CHAR_2_QSTRING(__tr("Step 2: Script Description")));
+	addPage(m_pPage2, _CHAR_2_QSTRING(_i18n_("Step 2: Script Description")));
 /*
 	@quickhelp: QWidget_ScriptWizardPage3
 	@widget: Script wizard page 3
@@ -229,7 +229,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"You can choose to include all or part of your appearance\n"\
 		"settings with the script.\n"\
 		"If you are going to distribute the script, it is recommended you\n"\
@@ -241,25 +241,25 @@ KviScriptWizard::KviScriptWizard()
 
 	g->addWidget(l, 0, 1);
 
-	m_pSaveColorsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save color and style settings")), m_pPage3);
+	m_pSaveColorsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save color and style settings")), m_pPage3);
 	m_pSaveColorsCheck->setChecked(true);
 	g->addWidget(m_pSaveColorsCheck, 1, 1);
 
-	m_pSaveBackgroundsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save background images")), m_pPage3);
+	m_pSaveBackgroundsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save background images")), m_pPage3);
 	m_pSaveBackgroundsCheck->setChecked(true);
 	g->addWidget(m_pSaveBackgroundsCheck, 2, 1);
 
-	m_pSaveFontsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save font settings")), m_pPage3);
+	m_pSaveFontsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save font settings")), m_pPage3);
 	m_pSaveFontsCheck->setChecked(true);
 	g->addWidget(m_pSaveFontsCheck, 3, 1);
 
-	m_pSaveTextColorsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save text colors")), m_pPage3);
+	m_pSaveTextColorsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save text colors")), m_pPage3);
 	m_pSaveTextColorsCheck->setChecked(true);
 	g->addWidget(m_pSaveTextColorsCheck, 4, 1);
 
 	g->setRowStretch(0, 1);
 
-	addPage(m_pPage3, _CHAR_2_QSTRING(__tr("Step 3: Included Settings")));
+	addPage(m_pPage3, _CHAR_2_QSTRING(_i18n_("Step 3: Included Settings")));
 /*
 	@quickhelp: QWidget_ScriptWizardPage4
 	@widget: Script wizard page 4
@@ -283,7 +283,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Select the options below to save current aliases, event\n"\
 		"handlers, popup menus or user toolbar items. \n")
 		), m_pPage4
@@ -291,29 +291,29 @@ KviScriptWizard::KviScriptWizard()
 
 	g->addWidget(l, 0, 1);
 
-	m_pSaveAliasesCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save aliases")), m_pPage4);
+	m_pSaveAliasesCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save aliases")), m_pPage4);
 	m_pSaveAliasesCheck->setChecked(true);
 	g->addWidget(m_pSaveAliasesCheck, 1, 1);
 
-	m_pSaveEventsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save event handlers")), m_pPage4);
+	m_pSaveEventsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save event handlers")), m_pPage4);
 	m_pSaveEventsCheck->setChecked(true);
 	g->addWidget(m_pSaveEventsCheck, 2, 1);
 
-	m_pSavePopupsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save popups")), m_pPage4);
+	m_pSavePopupsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save popups")), m_pPage4);
 	m_pSavePopupsCheck->setChecked(true);
 	g->addWidget(m_pSavePopupsCheck, 3, 1);
 
-	m_pSaveToolbarCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save user toolbar")), m_pPage4);
+	m_pSaveToolbarCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save user toolbar")), m_pPage4);
 	m_pSaveToolbarCheck->setChecked(true);
 	g->addWidget(m_pSaveToolbarCheck, 4, 1);
 
-	m_pSaveRawEventsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save raw event handlers")), m_pPage4);
+	m_pSaveRawEventsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save raw event handlers")), m_pPage4);
 	m_pSaveRawEventsCheck->setChecked(true);
 	g->addWidget(m_pSaveRawEventsCheck, 5, 1);
 
 	g->setRowStretch(0, 1);
 
-	addPage(m_pPage4, _CHAR_2_QSTRING(__tr("Step 4: Script Elements")));
+	addPage(m_pPage4, _CHAR_2_QSTRING(_i18n_("Step 4: Script Elements")));
 /*
 	@quickhelp: QWidget_ScriptWizardPage5
 	@widget: Script wizard page 5
@@ -334,7 +334,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Select the options below for more settings to include\n"\
 		"with your script.")
 		), m_pPage5
@@ -342,25 +342,25 @@ KviScriptWizard::KviScriptWizard()
 
 	g->addWidget(l, 0, 1);
 
-	m_pSaveMessagesCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save default messages")), m_pPage5);
+	m_pSaveMessagesCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save default messages")), m_pPage5);
 	m_pSaveMessagesCheck->setChecked(true);
 	g->addWidget(m_pSaveMessagesCheck, 1, 1);
 
-	m_pSaveOutputRedirectionCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save output redirection options")), m_pPage5);
+	m_pSaveOutputRedirectionCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save output redirection options")), m_pPage5);
 	m_pSaveOutputRedirectionCheck->setChecked(true);
 	g->addWidget(m_pSaveOutputRedirectionCheck, 2, 1);
 
-	m_pSaveCTCPOptionsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save CTCP options")), m_pPage5);
+	m_pSaveCTCPOptionsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save CTCP options")), m_pPage5);
 	m_pSaveCTCPOptionsCheck->setChecked(true);
 	g->addWidget(m_pSaveCTCPOptionsCheck, 3, 1);
 
-	m_pSaveIrcEngineOptionsCheck = new QCheckBox(_CHAR_2_QSTRING(__tr("Save IRC engine options")), m_pPage5);
+	m_pSaveIrcEngineOptionsCheck = new QCheckBox(_CHAR_2_QSTRING(_i18n_("Save IRC engine options")), m_pPage5);
 	m_pSaveIrcEngineOptionsCheck->setChecked(true);
 	g->addWidget(m_pSaveIrcEngineOptionsCheck, 4, 1);
 
 	g->setRowStretch(0, 1);
 
-	addPage(m_pPage5, _CHAR_2_QSTRING(__tr("Step 5: More Settings")));
+	addPage(m_pPage5, _CHAR_2_QSTRING(_i18n_("Step 5: More Settings")));
 /*
 	@quickhelp: QWidget_ScriptWizardPage6
 	@widget: Script wizard page 6
@@ -381,7 +381,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Add the additional files that you wish to distribute\n"\
 		"with your script.\n")
 		), m_pPage6
@@ -392,18 +392,18 @@ KviScriptWizard::KviScriptWizard()
 	m_pExtraFilesBox = new KviListBox(m_pPage6);
 	g->addMultiCellWidget(m_pExtraFilesBox, 1, 1, 1, 2);
 
-	KviPushButton *b = new KviPushButton(__tr("&Add..."), m_pPage6);
+	KviPushButton *b = new KviPushButton(_i18n_("&Add..."), m_pPage6);
 	connect(b, SIGNAL(clicked()), this, SLOT(addExtraFile()));
 	g->addWidget(b, 2, 1);
 
-	m_pRemoveExtra = new KviPushButton(__tr("&Remove"), m_pPage6);
+	m_pRemoveExtra = new KviPushButton(_i18n_("&Remove"), m_pPage6);
 	m_pRemoveExtra->setEnabled(false);
 	connect(m_pRemoveExtra, SIGNAL(clicked()), this, SLOT(removeSelectedExtraFiles()));
 	g->addWidget(m_pRemoveExtra, 2, 2);
 
 	g->setRowStretch(1, 1);
 
-	addPage(m_pPage6, _CHAR_2_QSTRING(__tr("Step 6: Additional Files")));
+	addPage(m_pPage6, _CHAR_2_QSTRING(_i18n_("Step 6: Additional Files")));
 /*
 	@quickhelp: QWidget_ScriptWizardPage7
 	@widget: Script wizard page 7
@@ -424,7 +424,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Enter the KVI++ code that you wish to execute immediately\n"\
 		"after your script has been completely loaded. If your script\n"\
 		"requires KVIrc to be restarted, this is a good place to ask\n"\
@@ -441,7 +441,7 @@ KviScriptWizard::KviScriptWizard()
 
 	g->setRowStretch(1, 1);
 
-	addPage(m_pPage7, _CHAR_2_QSTRING(__tr("Step 7: Code Epilogue")));
+	addPage(m_pPage7, _CHAR_2_QSTRING(_i18n_("Step 7: Code Epilogue")));
 
 	m_pPage8 = new QWidget(this, "ScriptWizardPage8");
 	g        = new QGridLayout(m_pPage8, 2, 2, 10, 4);
@@ -458,7 +458,7 @@ KviScriptWizard::KviScriptWizard()
 			ol->setBackgroundPixmap(pix);
 	}
 
-	l = new KviLabel(_CHAR_2_QSTRING(__tr(
+	l = new KviLabel(_CHAR_2_QSTRING(_i18n_(
 		"Check the following option if you want a tar.gz archive of\n"\
 		"your script distribution to be created.\n")
 		), m_pPage8
@@ -466,13 +466,13 @@ KviScriptWizard::KviScriptWizard()
 
 	g->addWidget(l, 0, 1);
 
-	m_pCreateTarball = new QCheckBox(__tr("Create tar.gz distribution package"), m_pPage8);
+	m_pCreateTarball = new QCheckBox(_i18n_("Create tar.gz distribution package"), m_pPage8);
 	m_pCreateTarball->setChecked(true);
 	g->addWidget(m_pCreateTarball, 1, 1);
 
 	g->setRowStretch(0, 1);
 
-	addPage(m_pPage8, _CHAR_2_QSTRING(__tr("Step 8: Script Packaging")));
+	addPage(m_pPage8, _CHAR_2_QSTRING(_i18n_("Step 8: Script Packaging")));
 
 	connect(this, SIGNAL(helpClicked()), g_pApp, SLOT(slot_whatIsThisRequest()));
 	setFinishEnabled(m_pPage8, true);
