@@ -42,6 +42,7 @@
 KviSimpleEditor::KviSimpleEditor(QWidget *parent)
 	: QTextEdit(parent)
 {
+	m_pAccel = new KviAccel(this, parent);
 	m_lastFindWidgetPosition = QPoint(0, 0);
 	m_bRecordingKeystrokes   = false;
 	m_szFileName             = "";
@@ -69,6 +70,7 @@ KviSimpleEditor::~KviSimpleEditor()
 {
 	closeFile(); // Cancel does nothing here
 
+	delete m_pAccel;        m_pAccel        = 0;
 	delete m_pHighlighter;  m_pHighlighter  = 0;
 	delete m_pFindWidget;   m_pFindWidget   = 0;
 	delete m_pKeystrokes;   m_pKeystrokes   = 0;
@@ -83,7 +85,7 @@ bool KviSimpleEditor::closeFile()
 	QString msg;
 	msg.sprintf(
 		"The file %s has been modified\nDo you wish to save your changes?",
-		m_szFileName.isEmpty() ? "Untitled" : m_szFileName.ascii()
+		m_szFileName.isEmpty() ? "Untitled" : (const char *) m_szFileName.utf8()
 	);
 	int ret = KviMessageBox::warningYesNoCancel(msg, "Warning", this);
 	if( ret == KviMessageBox::Yes ) {
@@ -159,7 +161,7 @@ bool KviSimpleEditor::saveFile(const QString &filename)
 			QString line = text(i);
 			// Huh?
 			if( (f.writeBlock(line, line.length()) != (int) line.length()) || (f.writeBlock("\n", 1) != 1) ) {
-				debug("Error writing to file:\n%s", line.ascii());
+				debug("Error writing to file:\n%s", (const char *) line.utf8());
 				i++;
 			}
 			progress = (i * 100) / paragraphs();
@@ -187,7 +189,10 @@ bool KviSimpleEditor::saveFileAs()
 	QFileInfo fi(newName);
 	if( fi.exists() ) {
 		QString msg;
-		msg.sprintf("The file %s already exists!\nDo you wish to overwrite it?", newName.ascii());
+		msg.sprintf(
+			"The file %s already exists!\nDo you wish to overwrite it?",
+			(const char *) newName.utf8()
+		);
 		int result = KviMessageBox::warningYesNo(msg, "Warning", this);
 		if( result == KviMessageBox::No )
 			return false; // Aborted
@@ -497,9 +502,6 @@ void KviSimpleEditor::replaceAllInSelection()
 	int index = indexFrom;
 	for( int para = paraFrom; para <= paraTo; ) {
 		QString line = text(para);
-#if 0
-		debug("line = \"%s\"", text(para).ascii());
-#endif
 		index = line.find(toFind, index, m_pFindWidget->m_pCaseSensitiveCheckBox->isChecked());
 		if( (para == paraTo) && (index + (int) toFind.length() > indexTo) )
 			break; // Ran past the selection
@@ -748,21 +750,21 @@ void KviSimpleEditor::contextPopup()
 	m_pContextPopup->clear();
 	m_pContextPopup->insertTearOffHandle();
 
-	int id = m_pContextPopup->insertItem("&Undo", this, SLOT(undo()), KviAccel::stringToKey("Ctrl+Z"));
+	int id = m_pContextPopup->insertItem("&Undo", this, SLOT(undo()), m_pAccel->shortcut("Ctrl+Z"));
 	if( !isUndoAvailable() )
 		m_pContextPopup->setItemEnabled(id, false);
-	id = m_pContextPopup->insertItem("&Redo", this, SLOT(redo()), KviAccel::stringToKey("Ctrl+Y"));
+	id = m_pContextPopup->insertItem("&Redo", this, SLOT(redo()), m_pAccel->shortcut("Ctrl+Y"));
 	if( !isRedoAvailable() )
 		m_pContextPopup->setItemEnabled(id, false);
 	m_pContextPopup->insertSeparator();
 
-	id = m_pContextPopup->insertItem("&Cut", this, SLOT(cut()), KviAccel::stringToKey("Ctrl+X"));
+	id = m_pContextPopup->insertItem("&Cut", this, SLOT(cut()), m_pAccel->shortcut("Ctrl+X"));
 	if( !hasSelectedText() )
 		m_pContextPopup->setItemEnabled(id, false);
-	id = m_pContextPopup->insertItem("&Copy", this, SLOT(copy()), KviAccel::stringToKey("Ctrl+C"));
+	id = m_pContextPopup->insertItem("&Copy", this, SLOT(copy()), m_pAccel->shortcut("Ctrl+C"));
 	if( !hasSelectedText() )
 		m_pContextPopup->setItemEnabled(id, false);
-	id = m_pContextPopup->insertItem("&Paste", this, SLOT(paste()), KviAccel::stringToKey("Ctrl+V"));
+	id = m_pContextPopup->insertItem("&Paste", this, SLOT(paste()), m_pAccel->shortcut("Ctrl+V"));
 	QString t = KviApplication::clipboard()->text();
 	if( t.isEmpty() )
 		m_pContextPopup->setItemEnabled(id, false);
@@ -772,58 +774,58 @@ void KviSimpleEditor::contextPopup()
 	m_pFindPopup->insertTearOffHandle();
 
 	m_pFindPopup->insertItem(m_pFindWidget->isVisible() ? "Hide &Find Widget" : "Show &Find Widget",
-		this, SLOT(toggleFindWidget()), KviAccel::stringToKey("Ctrl+F")
+		this, SLOT(toggleFindWidget()), m_pAccel->shortcut("Ctrl+F")
 	);
 	m_pFindPopup->insertSeparator();
 
 	QString toFind = m_pFindWidget->m_pFindStringEdit->text();
 	bool bHasToFind = !toFind.isEmpty();
-	id = m_pFindPopup->insertItem("Find &Next", this, SLOT(findNext()), KviAccel::stringToKey("Ctrl+N"));
+	id = m_pFindPopup->insertItem("Find &Next", this, SLOT(findNext()), m_pAccel->shortcut("Ctrl+N"));
 	if( !bHasToFind )
 		m_pFindPopup->setItemEnabled(id, false);
-	id = m_pFindPopup->insertItem("Find &Previous", this, SLOT(findPrev()), KviAccel::stringToKey("Ctrl+P"));
+	id = m_pFindPopup->insertItem("Find &Previous", this, SLOT(findPrev()), m_pAccel->shortcut("Ctrl+P"));
 	if( !bHasToFind )
 		m_pFindPopup->setItemEnabled(id, false);
-	id = m_pFindPopup->insertItem("Find Next &Regexp", this, SLOT(findNextRegexp()), KviAccel::stringToKey("Ctrl+B"));
+	id = m_pFindPopup->insertItem("Find Next &Regexp", this, SLOT(findNextRegexp()), m_pAccel->shortcut("Ctrl+B"));
 	if( !bHasToFind )
 		m_pFindPopup->setItemEnabled(id, false);
-	id = m_pFindPopup->insertItem("Find Previous Reg&exp", this, SLOT(findPrevRegexp()), KviAccel::stringToKey("Ctrl+G"));
+	id = m_pFindPopup->insertItem("Find Previous Reg&exp", this, SLOT(findPrevRegexp()), m_pAccel->shortcut("Ctrl+G"));
 	if( !bHasToFind )
 		m_pFindPopup->setItemEnabled(id, false);
 	m_pFindPopup->insertSeparator();
 
-	id = m_pFindPopup->insertItem("Rep&lace", this, SLOT(replace()), KviAccel::stringToKey("Ctrl+J"));
+	id = m_pFindPopup->insertItem("Rep&lace", this, SLOT(replace()), m_pAccel->shortcut("Ctrl+J"));
 	if( !hasSelectedText() )
 		m_pFindPopup->setItemEnabled(id, false);
-	id = m_pFindPopup->insertItem("Replace &All", this, SLOT(replaceAll()), KviAccel::stringToKey("Ctrl+K"));
+	id = m_pFindPopup->insertItem("Replace &All", this, SLOT(replaceAll()), m_pAccel->shortcut("Ctrl+K"));
 	if( !bHasToFind )
 		m_pFindPopup->setItemEnabled(id, false);
-	id = m_pFindPopup->insertItem("Replace All (Re&gexp)", this, SLOT(replaceAllRegexp()), KviAccel::stringToKey("Ctrl+L"));
+	id = m_pFindPopup->insertItem("Replace All (Re&gexp)", this, SLOT(replaceAllRegexp()), m_pAccel->shortcut("Ctrl+L"));
 	if( !bHasToFind )
 		m_pFindPopup->setItemEnabled(id, false);
 	id = m_pFindPopup->insertItem(
-		"Replace All in &Selection", this, SLOT(replaceAllInSelection()), KviAccel::stringToKey("Ctrl+E")
+		"Replace All in &Selection", this, SLOT(replaceAllInSelection()), m_pAccel->shortcut("Ctrl+E")
 	);
 	if( !(bHasToFind && hasSelectedText()) )
 		m_pFindPopup->setItemEnabled(id, false);
 	id = m_pFindPopup->insertItem(
-		"Replace All &in Selection (regexp)", this, SLOT(replaceAllInSelectionRegexp()), KviAccel::stringToKey("Ctrl+D")
+		"Replace All &in Selection (regexp)", this, SLOT(replaceAllInSelectionRegexp()), m_pAccel->shortcut("Ctrl+D")
 	);
 	if( !(bHasToFind && hasSelectedText()) )
 		m_pFindPopup->setItemEnabled(id, false);
 	m_pContextPopup->insertItem("&Find", m_pFindPopup);
 	m_pContextPopup->insertSeparator();
 
-	id = m_pContextPopup->insertItem("&Save", this, SLOT(saveFile()), KviAccel::stringToKey("Ctrl+S"));
+	id = m_pContextPopup->insertItem("&Save", this, SLOT(saveFile()), m_pAccel->shortcut("Ctrl+S"));
 	if( !isModified() )
 		m_pContextPopup->setItemEnabled(id, false);
-	m_pContextPopup->insertItem("Save &As...", this, SLOT(saveFileAs()), KviAccel::stringToKey("Ctrl+A"));
+	m_pContextPopup->insertItem("Save &As...", this, SLOT(saveFileAs()), m_pAccel->shortcut("Ctrl+A"));
 	m_pContextPopup->insertSeparator();
 
 	m_pContextPopup->insertItem(m_bRecordingKeystrokes ? "Stop &Recording Keystrokes" : "&Record Keystrokes",
-		this, SLOT(recordKeystrokes()), KviAccel::stringToKey("Ctrl+R")
+		this, SLOT(recordKeystrokes()), m_pAccel->shortcut("Ctrl+R")
 	);
-	id = m_pContextPopup->insertItem("Replay Keys&trokes", this, SLOT(replayKeystrokes()), KviAccel::stringToKey("Ctrl+T"));
+	id = m_pContextPopup->insertItem("Replay Keys&trokes", this, SLOT(replayKeystrokes()), m_pAccel->shortcut("Ctrl+T"));
 	if( m_bRecordingKeystrokes || (m_pKeystrokes->count() == 0) )
 		m_pContextPopup->setItemEnabled(id, false);
 	m_pContextPopup->insertSeparator();
