@@ -860,7 +860,7 @@ void fserve_plugin_config()
 bool fserve_plugin_command_fserve(KviPluginCommandStruct *cmd)
 {
 	if( !g_bServerActive ) {
-		cmd->window->output(KVI_OUT_INTERNAL, __tr("[fserve] The file server is not active"));
+		cmd->window->output(KVI_OUT_INTERNAL, _i18n_("[fserve] The file server is not active"));
 		return true;
 	}
 	if( cmd->params->count() < 2 ) {
@@ -870,16 +870,16 @@ bool fserve_plugin_command_fserve(KviPluginCommandStruct *cmd)
 	if( kvi_strEqualCI(kvirc_plugin_param(cmd, 1), "list") ) {
 		int total = 0;
 		for(KviFServeSession *s = g_pSessions->first(); s; s = g_pSessions->next() ) {
-			cmd->window->output(KVI_OUT_INTERNAL, __tr("%cSession: %s@%s"), KVI_TEXT_BOLD, s->nick.ptr(), s->address.ptr());
-			cmd->window->output(KVI_OUT_INTERNAL, __tr("Current credit: %s"),    s->credit.ptr());
-			cmd->window->output(KVI_OUT_INTERNAL, __tr("Current directory: %s"), s->currentDir.ptr());
+			cmd->window->output(KVI_OUT_INTERNAL, _i18n_("%cSession: %s@%s"), KVI_TEXT_BOLD, s->nick.ptr(), s->address.ptr());
+			cmd->window->output(KVI_OUT_INTERNAL, _i18n_("Current credit: %s"),    s->credit.ptr());
+			cmd->window->output(KVI_OUT_INTERNAL, _i18n_("Current directory: %s"), s->currentDir.ptr());
 			total++;
 		}
-		cmd->window->output(KVI_OUT_INTERNAL, __tr("[fserve] Total: %d running sessions"), total);
+		cmd->window->output(KVI_OUT_INTERNAL, _i18n_("[fserve] Total: %d running sessions"), total);
 	} else if( kvi_strEqualCI(kvirc_plugin_param(cmd, 1), "boot") ) {
 		if( cmd->params->count() < 3 ) {
 			cmd->error = KVI_ERROR_MissingParameter;
-			cmd->errorstr = __tr("The 'boot' operation requires a target (<nick>@<address>)");
+			cmd->errorstr = _i18n_("The 'boot' operation requires a target (<nick>@<address>)");
 			return false;
 		}
 		KviStr address = kvirc_plugin_param(cmd, 2);
@@ -887,17 +887,17 @@ bool fserve_plugin_command_fserve(KviPluginCommandStruct *cmd)
 		KviFServeSession *s = fserve_findRunningSessionByNickAndIp(nick.ptr(), address.ptr());
 		if( !s ) {
 			cmd->error = KVI_ERROR_InvalidParameter;
-			cmd->errorstr = __tr("Session not found");
+			cmd->errorstr = _i18n_("Session not found");
 			return false;
 		}
 		s->pWnd->output(KVI_OUT_OWN, "[fserve >> %s] Your session has been closed by the system administrator.", s->nick.ptr());
 		((KviDccChat *) (s->pWnd))->sendData("[fserve] Your session has been closed by the system administrator.");
 		fserve_closeSession(s);
-		cmd->window->output(KVI_OUT_INTERNAL, __tr("[fserve] Session closed (%s@%s)"), nick.ptr(), address.ptr());
+		cmd->window->output(KVI_OUT_INTERNAL, _i18n_("[fserve] Session closed (%s@%s)"), nick.ptr(), address.ptr());
 	} else if( kvi_strEqualCI(kvirc_plugin_param(cmd, 1), "credit") ) {
 		if( cmd->params->count() < 4 ) {
 			cmd->error = KVI_ERROR_MissingParameter;
-			cmd->errorstr = __tr("The 'credit' operation requires a target (<nick>@<address>) and a credit value");
+			cmd->errorstr = _i18n_("The 'credit' operation requires a target (<nick>@<address>) and a credit value");
 			return false;
 		}
 		KviStr address = kvirc_plugin_param(cmd, 2);
@@ -905,14 +905,14 @@ bool fserve_plugin_command_fserve(KviPluginCommandStruct *cmd)
 		KviFServeSession *s = fserve_findRunningSessionByNickAndIp(nick.ptr(), address.ptr());
 		if( !s ) {
 			cmd->error = KVI_ERROR_InvalidParameter;
-			cmd->errorstr = __tr("Session not found");
+			cmd->errorstr = _i18n_("Session not found");
 			return false;
 		}
 		KviStr credit = kvirc_plugin_param(cmd, 3);
 		if( !credit.isUnsignedNum() ) {
 			if( !kvi_strEqualCI(credit.ptr(), "unlimited") ) {
 				cmd->error = KVI_ERROR_InvalidParameter;
-				cmd->errorstr = __tr("The credit must be an unsigned integer or the word 'unlimited'");
+				cmd->errorstr = _i18n_("The credit must be an unsigned integer or the word 'unlimited'");
 				return false;
 			}
 		}
@@ -921,13 +921,13 @@ bool fserve_plugin_command_fserve(KviPluginCommandStruct *cmd)
 		s->pWnd->output(KVI_OUT_OWN, "[fserve >> %s] %s", s->nick.ptr(), tmp.ptr());
 		tmp.prepend("[fserve] ");
 		((KviDccChat *) (s->pWnd))->sendData(tmp.ptr());
-		cmd->window->output(KVI_OUT_INTERNAL, __tr("[fserve] Credit for session %s@%s successfully set to %s"), nick.ptr(), address.ptr(), credit.ptr());
+		cmd->window->output(KVI_OUT_INTERNAL, _i18n_("[fserve] Credit for session %s@%s successfully set to %s"), nick.ptr(), address.ptr(), credit.ptr());
 	} else if( kvi_strEqualCI(kvirc_plugin_param(cmd, 1), "config") ) {
 		fserve_plugin_config();
 		return true;
 	} else {
 		cmd->error = KVI_ERROR_InvalidOperation;
-		cmd->errorstr = __tr("Available operations are: 'list', 'boot' and 'credit'");
+		cmd->errorstr = _i18n_("Available operations are: 'list', 'boot' and 'credit'");
 		return false;
 	}
 	return true;
@@ -1150,12 +1150,12 @@ KviPlugin kvirc_plugin =
 KviFServeConfigDialog::KviFServeConfigDialog()
 	: KviTabDialog()
 {
-	setCaption(__tr("File server configuration"));
+	setCaption(_i18n_("File server configuration"));
 
-	QFrame      *tab = addPage(_CHAR_2_QSTRING(__tr("Main")));
+	QFrame      *tab = addPage(_CHAR_2_QSTRING(_i18n_("Main")));
 	QGridLayout *g   = new QGridLayout(tab, 5, 1, 10, 4);
 
-	KviBoolSelector *b = new KviBoolSelector(tab, __tr("Activate file server"), &(g_bServerActive), true);
+	KviBoolSelector *b = new KviBoolSelector(tab, _i18n_("Activate file server"), &(g_bServerActive), true);
 	g->addWidget(b, 0, 0);
 
 	QFrame *r = new QFrame(tab);
@@ -1163,7 +1163,7 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	g->addWidget(r, 1, 0);
 
 	KviLabel *l = new KviLabel(
-		__tr("A misconfigured file server may allow remote users to download " \
+		_i18n_("A misconfigured file server may allow remote users to download " \
 		"unwanted files from your filesystem.\n" \
 		"Please check the settings twice before enabling the service.\n" \
 		"It is also not recommended to leave the service " \
@@ -1175,20 +1175,20 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	r->setFrameStyle(QFrame::Sunken | QFrame::HLine);
 	g->addWidget(r, 3, 0);
 
-	KviStringSelector *s = new KviStringSelector(tab, __tr("File server root "), &(g_szFServeRoot), g_bServerActive);
+	KviStringSelector *s = new KviStringSelector(tab, _i18n_("File server root "), &(g_szFServeRoot), g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), s, SLOT(setEnabled(bool)));
 	g->addWidget(s, 4, 0);
 
 	g->setRowStretch(2, 2);
 
-	tab = addPage(_CHAR_2_QSTRING(__tr("Public access")));
+	tab = addPage(_CHAR_2_QSTRING(_i18n_("Public access")));
 	g   = new QGridLayout(tab, 7, 1, 10, 4);
 
-	s = new KviStringSelector(tab, __tr("Password"), &(g_szFServePass), g_bServerActive);
+	s = new KviStringSelector(tab, _i18n_("Password"), &(g_szFServePass), g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), s, SLOT(setEnabled(bool)));
 	g->addMultiCellWidget(s, 0, 0, 0, 4);
 
-	s = new KviStringSelector(tab, __tr("Initial credit"), &(g_szInitialCredit), g_bServerActive);
+	s = new KviStringSelector(tab, _i18n_("Initial credit"), &(g_szInitialCredit), g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), s, SLOT(setEnabled(bool)));
 	g->addMultiCellWidget(s, 1, 1, 0, 4);
 
@@ -1196,7 +1196,7 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	r->setFrameStyle(QFrame::Sunken | QFrame::HLine);
 	g->addMultiCellWidget(r, 2, 2, 0, 4);
 
-	l = new KviLabel(__tr("Give "), tab);
+	l = new KviLabel(_i18n_("Give "), tab);
 	l->setEnabled(g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), l, SLOT(setEnabled(bool)));
 	g->addWidget(l, 3, 0);
@@ -1209,7 +1209,7 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	connect(b, SIGNAL(toggled(bool)), m_pRatioGiveEdit, SLOT(setEnabled(bool)));
 	g->addWidget(m_pRatioGiveEdit, 3, 1);
 
-	l = new KviLabel(__tr(" byte(s) for each block of "), tab);
+	l = new KviLabel(_i18n_(" byte(s) for each block of "), tab);
 	l->setEnabled(g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), l, SLOT(setEnabled(bool)));
 	l->setMinimumSize(l->sizeHint());
@@ -1222,7 +1222,7 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	connect(b, SIGNAL(toggled(bool)), m_pRatioTakeEdit, SLOT(setEnabled(bool)));
 	g->addWidget(m_pRatioTakeEdit, 3, 3);
 
-	l = new KviLabel(__tr(" byte(s) received"), tab);
+	l = new KviLabel(_i18n_(" byte(s) received"), tab);
 	l->setEnabled(g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), l, SLOT(setEnabled(bool)));
 	l->setMinimumSize(l->sizeHint());
@@ -1233,20 +1233,20 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	r->setMinimumHeight(r->frameWidth() << 1);
 	g->addMultiCellWidget(r, 4, 4, 0, 4);
 
-	KviBoolSelector *b1 = new KviBoolSelector(tab, __tr("Listen to PRIVMGS <mynick> !fserve [password]"), &(g_bListenToPrivmsg), g_bServerActive);
+	KviBoolSelector *b1 = new KviBoolSelector(tab, _i18n_("Listen to PRIVMGS <mynick> !fserve [password]"), &(g_bListenToPrivmsg), g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), b1, SLOT(setEnabled(bool)));
 	g->addMultiCellWidget(b1, 5, 5, 0, 4);
 
 	KviIntegerSelector *i1 = new KviIntegerSelector(
-		tab, __tr("Max running sessions "), &(g_uMaxRunningSessions), KviIntegerSelector::UInt, 0, 65535, 1, g_bServerActive
+		tab, _i18n_("Max running sessions "), &(g_uMaxRunningSessions), KviIntegerSelector::UInt, 0, 65535, 1, g_bServerActive
 	);
 	connect(b, SIGNAL(toggled(bool)), i1, SLOT(setEnabled(bool)));
 	g->addMultiCellWidget(i1, 6, 6, 0, 4);
 
-	tab = addPage(_CHAR_2_QSTRING(__tr("MOTD")));
+	tab = addPage(_CHAR_2_QSTRING(_i18n_("MOTD")));
 	g   = new QGridLayout(tab, 2, 1, 10, 4);
 
-	b1 = new KviBoolSelector(tab, __tr("Show MOTD after login"), &(g_bShowMotdAtLogin), g_bServerActive);
+	b1 = new KviBoolSelector(tab, _i18n_("Show MOTD after login"), &(g_bShowMotdAtLogin), g_bServerActive);
 	connect(b, SIGNAL(toggled(bool)), b1, SLOT(setEnabled(bool)));
 	g->addWidget(b1, 0, 0);
 
@@ -1257,7 +1257,7 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	g->addWidget(m_pMotdEdit, 1, 0);
 	g->setRowStretch(1, 2);
 
-	tab = addPage(_CHAR_2_QSTRING(__tr("Banned IP addresses")));
+	tab = addPage(_CHAR_2_QSTRING(_i18n_("Banned IP addresses")));
 	g   = new QGridLayout(tab, 1, 3, 10, 4);
 
 	m_pBannedIpEdit = new KviLineEdit(tab);
@@ -1265,13 +1265,13 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 	connect(b, SIGNAL(toggled(bool)), m_pBannedIpEdit, SLOT(setEnabled(bool)));
 	g->addWidget(m_pBannedIpEdit, 0, 0);
 
-	KviPushButton *btn = new KviPushButton(__tr("<-- Add"), tab);
+	KviPushButton *btn = new KviPushButton(_i18n_("<-- Add"), tab);
 	btn->setEnabled(g_bServerActive);
 	connect(b,   SIGNAL(toggled(bool)), btn,  SLOT(setEnabled(bool)));
 	connect(btn, SIGNAL(clicked()),     this, SLOT(addBannedIp()));
 	g->addWidget(btn, 0, 1);
 
-	btn = new KviPushButton(__tr("Remove selected"), tab);
+	btn = new KviPushButton(_i18n_("Remove selected"), tab);
 	btn->setEnabled(g_bServerActive);
 	connect(b,   SIGNAL(toggled(bool)), btn,  SLOT(setEnabled(bool)));
 	connect(btn, SIGNAL(clicked()),     this, SLOT(removeBannedIp()));
@@ -1287,12 +1287,12 @@ KviFServeConfigDialog::KviFServeConfigDialog()
 
 	g->setRowStretch(1, 2);
 
-	setButtonCancelText(__tr("Cancel"));
-
+	setButtonCancel();
 }
 
 KviFServeConfigDialog::~KviFServeConfigDialog()
 {
+	// Nothing here
 }
 
 void KviFServeConfigDialog::done(int r)
