@@ -50,7 +50,7 @@ KviStatController *g_pStatPluginController    = 0;
 /**
  * Usage text.
  */
-const char *usageText = __tr(
+const char *usageText = _i18n_(
 	"\nUsage:\nSTATS [option] - see and manipulate your statistics.\n"
 	"If used without options it shows number of words for current window type, "
 	"and if it is typed in a chan window it shows the number of words said on "
@@ -94,35 +94,35 @@ void stat_plugin_processJoinStats(KviStatChan *c, KviWindow *window)
 	switch( g_pStatPluginController->joinStatType() ) {
 		case ShowFullStatsOnJoin: {
 			if( c->joins() == 1 )
-				window->output(KVI_OUT_INFO, (__tr("You have joined %s once.")), window->caption());
+				window->output(KVI_OUT_INFO, (_i18n_("You have joined %s once.")), window->caption());
 			else
-				window->output(KVI_OUT_INFO, (__tr("You have joined %s for %u times.")), window->caption(), c->joins());
-			window->output(KVI_OUT_INFO, (__tr("Full stats for %s:")), window->caption());
-			window->output(KVI_OUT_INFO, _CHAR_2_QSTRING(__tr("    Words: %d\n    Kicks: %u\n    Bans: %u\n    Topic changes: %u")), c->words(), c->kicks(), c->bans(), c->topics());
+				window->output(KVI_OUT_INFO, (_i18n_("You have joined %s for %u times.")), window->caption(), c->joins());
+			window->output(KVI_OUT_INFO, (_i18n_("Full stats for %s:")), window->caption());
+			window->output(KVI_OUT_INFO, _CHAR_2_QSTRING(_i18n_("    Words: %d\n    Kicks: %u\n    Bans: %u\n    Topic changes: %u")), c->words(), c->kicks(), c->bans(), c->topics());
 		} break;
 
 		case ShowCustomStatsOnJoin: {
 			if( g_pStatPluginController->showJoins() ) {
 				if( c->joins() == 1 )
-					window->output(KVI_OUT_INFO, (__tr("You have joined %s once.")), window->caption());
+					window->output(KVI_OUT_INFO, (_i18n_("You have joined %s once.")), window->caption());
 				else
-					window->output(KVI_OUT_INFO, (__tr("You have joined %s for %u times.")), window->caption(), c->joins());
+					window->output(KVI_OUT_INFO, (_i18n_("You have joined %s for %u times.")), window->caption(), c->joins());
 			}
 			if( g_pStatPluginController->showKicks() ||
 				g_pStatPluginController->showWords() ||
 				g_pStatPluginController->showBans()  ||
 				g_pStatPluginController->showTopics() )
 			{
-				window->output(KVI_OUT_INFO, (__tr("Stats for %s:")), window->caption());
+				window->output(KVI_OUT_INFO, (_i18n_("Stats for %s:")), window->caption());
 			}
 			if( g_pStatPluginController->showWords() )
-				window->output(KVI_OUT_INFO, (__tr("    Words spoken: %d.")), c->words());
+				window->output(KVI_OUT_INFO, (_i18n_("    Words spoken: %d.")), c->words());
 			if( g_pStatPluginController->showKicks() )
-				window->output(KVI_OUT_INFO, (__tr("    Kicks given: %d.")), c->kicks());
+				window->output(KVI_OUT_INFO, (_i18n_("    Kicks given: %d.")), c->kicks());
 			if( g_pStatPluginController->showBans() )
-				window->output(KVI_OUT_INFO, (__tr("    Bans set: %d.")), c->bans());
+				window->output(KVI_OUT_INFO, (_i18n_("    Bans set: %d.")), c->bans());
 			if( g_pStatPluginController->showTopics() )
-				window->output(KVI_OUT_INFO, (__tr("    Topic changes: %d.")), c->topics());
+				window->output(KVI_OUT_INFO, (_i18n_("    Topic changes: %d.")), c->topics());
 		} break;
 	}
 }
@@ -155,7 +155,7 @@ bool stat_plugin_hook_addstat(KviPluginCommandStruct *cmd)
 				KviStatChan *stch = new KviStatChan(cmd->window->caption(), 1, numWords);
 				g_pStatPluginController->addChan(stch);
 
-				cmd->window->output(KVI_OUT_INFO, __tr("Added %s to stats."), cmd->window->caption());
+				cmd->window->output(KVI_OUT_INFO, _i18n_("Added %s to stats."), cmd->window->caption());
 				break;
 			}
 			c->addWords(numWords);
@@ -193,39 +193,39 @@ bool stat_plugin_command_stats(KviPluginCommandStruct *cmd)
 			case 'D': { // Detailed stats of current chan
 				if( cmd->window->type() == 1 ) { // This is a chan win
 					if( chan ) { // Got the chan in stats
-						s.sprintf(__tr("Stats for %s:\n"), cmd->window->caption());
+						s.sprintf(_i18n_("Stats for %s:\n"), cmd->window->caption());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("Joins: %u\nWords: %d\nKicks: %u\n"), chan->joins(), chan->words(), chan->kicks());
+						s.sprintf(_i18n_("Joins: %u\nWords: %d\nKicks: %u\n"), chan->joins(), chan->words(), chan->kicks());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("Bans: %u\nTopics: %u\n"), chan->bans(), chan->topics());
+						s.sprintf(_i18n_("Bans: %u\nTopics: %u\n"), chan->bans(), chan->topics());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 					} else { // Do not have it
-						s.sprintf(__tr("No stats for %s.\n"), cmd->window->caption());
+						s.sprintf(_i18n_("No stats for %s.\n"), cmd->window->caption());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 					}
 				} else { // Current window is not a chan window
 					if( cmd->window->type() == 0 ) { // @console
-						s.sprintf(__tr("Total number of:\n* IRC sessions: %d.\n"), g_pStatPluginController->numOnIrc());
+						s.sprintf(_i18n_("Total number of:\n* IRC sessions: %d.\n"), g_pStatPluginController->numOnIrc());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("* joins to channels: %d.\n"), g_pStatPluginController->numJoins());
+						s.sprintf(_i18n_("* joins to channels: %d.\n"), g_pStatPluginController->numJoins());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("* kicks given: %d.\n"), g_pStatPluginController->numKicks());
+						s.sprintf(_i18n_("* kicks given: %d.\n"), g_pStatPluginController->numKicks());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("* bans set: %d.\n* topic changes: %d.\n"), g_pStatPluginController->numBans(), g_pStatPluginController->numTopics());
+						s.sprintf(_i18n_("* bans set: %d.\n* topic changes: %d.\n"), g_pStatPluginController->numBans(), g_pStatPluginController->numTopics());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 						break;
 					}
 					if( cmd->window->type() == 2 ) { // Query
-						s.sprintf(__tr("Total queries stats:\n* number of words: %d.\n"), g_pStatPluginController->queriesWords());
+						s.sprintf(_i18n_("Total queries stats:\n* number of words: %d.\n"), g_pStatPluginController->queriesWords());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("* number of letters: %d.\n"), g_pStatPluginController->queriesLetters());
+						s.sprintf(_i18n_("* number of letters: %d.\n"), g_pStatPluginController->queriesLetters());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 						break;
 					}
 					if( cmd->window->type() == 3 ) { // DCC
-						s.sprintf(__tr("Total DCCs stats:\n* number of words: %d.\n"), g_pStatPluginController->dccsWords());
+						s.sprintf(_i18n_("Total DCCs stats:\n* number of words: %d.\n"), g_pStatPluginController->dccsWords());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
-						s.sprintf(__tr("* number of letters: %d.\n"), g_pStatPluginController->dccsLetters());
+						s.sprintf(_i18n_("* number of letters: %d.\n"), g_pStatPluginController->dccsLetters());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 						break;
 					}
@@ -233,12 +233,12 @@ bool stat_plugin_command_stats(KviPluginCommandStruct *cmd)
 			} break;
 
 			case 'o': { // Show total number of topics
-				s.sprintf(__tr("You have changed topic %d times.\n"), g_pStatPluginController->numTopics());
+				s.sprintf(_i18n_("You have changed topic %d times.\n"), g_pStatPluginController->numTopics());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'm': { // Show channel message
-				s.sprintf(__tr("/me has spoken %d words since %s!"),
+				s.sprintf(_i18n_("/me has spoken %d words since %s!"),
 					g_pStatPluginController->totalWords(),
 					g_pStatPluginController->startDate()
 				);
@@ -247,10 +247,10 @@ bool stat_plugin_command_stats(KviPluginCommandStruct *cmd)
 
 			case 'M': { // Show channel message, but with words from this chan
 				if( !chan ) {
-					s.sprintf(__tr("No stats for %s."), cmd->window->caption());
+					s.sprintf(_i18n_("No stats for %s."), cmd->window->caption());
 					cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 				} else {
-					s.sprintf(__tr("/me has spoken %d words on %s since %s!"),
+					s.sprintf(_i18n_("/me has spoken %d words on %s since %s!"),
 						chan->words(), cmd->window->caption(),
 						g_pStatPluginController->startDate()
 					);
@@ -264,40 +264,40 @@ bool stat_plugin_command_stats(KviPluginCommandStruct *cmd)
 			} break;
 
 			case 't': { // Just echo total words
-				s.sprintf(__tr("Total number of words %d.\n"), g_pStatPluginController->totalWords());
+				s.sprintf(_i18n_("Total number of words %d.\n"), g_pStatPluginController->totalWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'c': { // Channels words
-				s.sprintf(__tr("Words spoken on channels: %d.\n"), g_pStatPluginController->chansWords());
+				s.sprintf(_i18n_("Words spoken on channels: %d.\n"), g_pStatPluginController->chansWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'q': { // Queries words
-				s.sprintf(__tr("Words spoken on queries: %d.\n"), g_pStatPluginController->queriesWords());
+				s.sprintf(_i18n_("Words spoken on queries: %d.\n"), g_pStatPluginController->queriesWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'd': { // DCCs words
-				s.sprintf(__tr("Words spoken on DCCs: %d.\n"), g_pStatPluginController->dccsWords());
+				s.sprintf(_i18n_("Words spoken on DCCs: %d.\n"), g_pStatPluginController->dccsWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'k': { // Kicks given
-				s.sprintf(__tr("Total number of kicks given: %d.\n"), g_pStatPluginController->numKicks());
+				s.sprintf(_i18n_("Total number of kicks given: %d.\n"), g_pStatPluginController->numKicks());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'b': { // Bans set
-				s.sprintf(__tr("Total number of bans set: %d.\n"), g_pStatPluginController->numBans());
+				s.sprintf(_i18n_("Total number of bans set: %d.\n"), g_pStatPluginController->numBans());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'j': { // Joins to the channel
 				if( !chan )
-					s.sprintf(__tr("No stats for %s.\n"), cmd->window->caption());
+					s.sprintf(_i18n_("No stats for %s.\n"), cmd->window->caption());
 				else
-					s.sprintf(__tr("Number of times you have joined %s: %u"), cmd->window->caption(), chan->joins());
+					s.sprintf(_i18n_("Number of times you have joined %s: %u"), cmd->window->caption(), chan->joins());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
@@ -307,76 +307,76 @@ bool stat_plugin_command_stats(KviPluginCommandStruct *cmd)
 
 			case 's': { // Save stats to file right now
 				g_pStatPluginController->slotSaveStats();
-				s.sprintf(__tr("Stats file saved.\n"));
+				s.sprintf(_i18n_("Stats file saved.\n"));
 				cmd->window->outputNoFmt(KVI_OUT_PLUGIN, s.ascii());
 			} break;
 
 			case 'R': { // Reset stats
 				if( g_pStatPluginController->doReset()) {
-					s.sprintf(__tr("All stats cleared.\n"));
+					s.sprintf(_i18n_("All stats cleared.\n"));
 					cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 				}
 			} break;
 
 			case 'x': { // Delete stats for given channel
 				if( cmd->params->count() < 3 ) {
-					s.sprintf(__tr("Missing argument to /STATS -x !\nUsage: /STATS -x #channel."));
+					s.sprintf(_i18n_("Missing argument to /STATS -x !\nUsage: /STATS -x #channel."));
 					cmd->window->outputNoFmt(KVI_OUT_ERROR, s.ascii());
 					break;
 				} else {
 					QString qs(cmd->params->at(2)->ptr());
 					if( !qs.contains("#") ) qs.insert(0, '#');
-					KviStatChan *sc = g_pStatPluginController->findStatChan(qs.latin1());
+					KviStatChan *sc = g_pStatPluginController->findStatChan((const char *) qs.utf8());
 					if( !sc ) {
-						s.sprintf(__tr("Channel %s is not in stats!"), qs.latin1());
+						s.sprintf(_i18n_("Channel %s is not in stats!"), (const char *) qs.utf8());
 						cmd->window->outputNoFmt(KVI_OUT_ERROR, s.ascii());
 					} else {
 						g_pStatPluginController->removeChan(sc);
-						s.sprintf(__tr("Channel %s removed from stats."), qs.latin1());
+						s.sprintf(_i18n_("Channel %s removed from stats."), (const char *) qs.utf8());
 						cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 					}
 				}
 			} break;
 
 			case 'S': { // This session stats
-				s.sprintf(__tr("Words spoken in this session: %u."), g_pStatPluginController->sessionWords());
+				s.sprintf(_i18n_("Words spoken in this session: %u."), g_pStatPluginController->sessionWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 'r': { // Session record
-				s.sprintf(__tr("Biggest number of words spoken in one session: %u."), g_pStatPluginController->wordsRecord());
+				s.sprintf(_i18n_("Biggest number of words spoken in one session: %u."), g_pStatPluginController->wordsRecord());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			default: {
-				s.sprintf(__tr("STATS: unknown option!\n"));
+				s.sprintf(_i18n_("STATS: unknown option!\n"));
 				cmd->window->outputNoFmt(KVI_OUT_ERROR, s.ascii());
 			}
 		}
 	} else { // Show stats for current window type
 		switch( cmd->window->type() ) {
 			case 0: { // @console
-				s.sprintf(__tr("Total number of IRC sessions: %d.\n"), g_pStatPluginController->numOnIrc());
+				s.sprintf(_i18n_("Total number of IRC sessions: %d.\n"), g_pStatPluginController->numOnIrc());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 1: { // Chan window; show stats for this chan
 				if( !chan ) {
-					s.sprintf(__tr("No stats for %s.\n"), cmd->window->caption());
+					s.sprintf(_i18n_("No stats for %s.\n"), cmd->window->caption());
 					cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 				} else {
-					s.sprintf(__tr("Words spoken on %s: %d.\n"), cmd->window->caption(), chan->words() );
+					s.sprintf(_i18n_("Words spoken on %s: %d.\n"), cmd->window->caption(), chan->words() );
 					cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 				}
 			} break;
 
 			case 2: { // Query window
-				s.sprintf(__tr("Words spoken on queries: %d.\n"), g_pStatPluginController->queriesWords());
+				s.sprintf(_i18n_("Words spoken on queries: %d.\n"), g_pStatPluginController->queriesWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 
 			case 3: { // DCC window
-				s.sprintf(__tr("Words spoken on DCCs: %d.\n"), g_pStatPluginController->dccsWords());
+				s.sprintf(_i18n_("Words spoken on DCCs: %d.\n"), g_pStatPluginController->dccsWords());
 				cmd->window->outputNoFmt(KVI_OUT_INFO, s.ascii());
 			} break;
 		}
@@ -402,7 +402,7 @@ bool stat_plugin_hook_on_topic(KviPluginCommandStruct *cmd)
 			g_pStatPluginController->addTotalJoin();
 
 			KviStr s;
-			s.sprintf(__tr("Added %s to stats."), cmd->window->caption());
+			s.sprintf(_i18n_("Added %s to stats."), cmd->window->caption());
 			cmd->window->outputNoFmt(KVI_OUT_INFO, s.ptr());
 
 			g_pStatPluginController->setCurrentChan(kvsc);
@@ -436,7 +436,7 @@ bool stat_plugin_hook_on_kick(KviPluginCommandStruct *cmd)
 			g_pStatPluginController->addTotalJoin();
 
 			KviStr s;
-			s.sprintf(__tr("Added %s to stats."), cmd->window->caption());
+			s.sprintf(_i18n_("Added %s to stats."), cmd->window->caption());
 			cmd->window->outputNoFmt(KVI_OUT_INFO, s.ptr());
 
 			g_pStatPluginController->setCurrentChan(kvsc);
@@ -464,7 +464,7 @@ bool stat_plugin_hook_on_ban(KviPluginCommandStruct *cmd)
 			g_pStatPluginController->addTotalJoin();
 
 			KviStr s;
-			s.sprintf(__tr("Added %s to stats."), cmd->window->caption());
+			s.sprintf(_i18n_("Added %s to stats."), cmd->window->caption());
 			cmd->window->outputNoFmt(KVI_OUT_INFO, s.ptr());
 
 			g_pStatPluginController->setCurrentChan(kvsc);
@@ -494,7 +494,7 @@ bool stat_plugin_hook_on_me_join(KviPluginCommandStruct *cmd)
 		g_pStatPluginController->addTotalJoin();
 
 		KviStr tmps;
-		tmps.sprintf(__tr("Added %s to stats.\n"), tmpchan->name());
+		tmps.sprintf(_i18n_("Added %s to stats.\n"), tmpchan->name());
 		cmd->window->outputNoFmt(KVI_OUT_INFO, tmps.ptr());
 	}
 
@@ -516,7 +516,7 @@ bool stat_plugin_hook_on_startup(KviPluginCommandStruct *cmd)
 {
 	QString s;
 	s.sprintf(
-		__tr("/echo -i=$icon(kvirc) Running $b\\KviStat$o\\ plugin version $b\\%s$o\\. Have fun!!"), KVISTAT_VERSION
+		_i18n_("/echo -i=$icon(kvirc) Running $b\\KviStat$o\\ plugin version $b\\%s$o\\. Have fun!!"), KVISTAT_VERSION
 	);
 	kvirc_plugin_simulate_typing(cmd->window, s);
 
@@ -542,9 +542,9 @@ bool stat_plugin_hook_on_disconnect(KviPluginCommandStruct *cmd)
 {
 	if( g_pStatPluginController->sessionWords() > g_pStatPluginController->wordsRecord() ) {
 		g_pStatPluginController->setWordsRecord(g_pStatPluginController->sessionWords());
-		cmd->window->outputNoFmt(KVI_OUT_INFO, __tr("[stats]: you have just beaten your session record!"));
+		cmd->window->outputNoFmt(KVI_OUT_INFO, _i18n_("[stats]: you have just beaten your session record!"));
 		cmd->window->output(KVI_OUT_INFO,
-			__tr("[stats]: now it is %c%d%c words!"),
+			_i18n_("[stats]: now it is %c%d%c words!"),
 			KVI_TEXT_BOLD, g_pStatPluginController->wordsRecord(), KVI_TEXT_BOLD
 		);
 	}
@@ -571,7 +571,7 @@ bool stat_plugin_command_stattray(KviPluginCommandStruct *cmd)
 		KviSysTrayWidget *w = kvirc_plugin_lookup_systray_widget(cmd->frame, "KviStatSysTray");
 		if( !w ) {
 			cmd->error = KVI_ERROR_InvalidParameter;
-			cmd->errorstr = __tr("No StatTray to undock");
+			cmd->errorstr = _i18n_("No StatTray to undock");
 			return false;
 		}
 
@@ -581,7 +581,7 @@ bool stat_plugin_command_stattray(KviPluginCommandStruct *cmd)
 		KviSysTrayWidget *w = kvirc_plugin_lookup_systray_widget(cmd->frame, "KviStatSysTray");
 		if( w ) {
 			cmd->error = KVI_ERROR_InvalidParameter;
-			cmd->errorstr = __tr("StatTray already docked in this frame");
+			cmd->errorstr = _i18n_("StatTray already docked in this frame");
 			return false;
 		}
 	}
@@ -631,7 +631,7 @@ bool stat_plugin_init(KviPluginCommandStruct *cmd)
 			if( !c ) {
 				c = new KviStatChan(wnd->caption());
 				g_pStatPluginController->addChan(c);
-				wnd->output(KVI_OUT_INFO, __tr("Added %s to stats.\n"), c->name());
+				wnd->output(KVI_OUT_INFO, _i18n_("Added %s to stats.\n"), c->name());
 			}
 
 			if( wnd->m_pInput )
@@ -774,10 +774,10 @@ void stat_plugin_config()
 KviPlugin kvirc_plugin =
 {
 	"Stat",
-	__tr("Stats plugin"),
+	_i18n_("Stats plugin"),
 	KVISTAT_VERSION,
 	"Krzysztof Godlewski\n<kristoff@poczta.wprost.pl>", // Author field
-	__tr("<html>"                                       // Description field
+	_i18n_("<html>"                                       // Description field
 		"This plugin creates and saves your session statistics.<br><br>"
 		"<b>/STATS</b>: check your statistics.<br>"
 		"<b>/STATTRAY</b>: control the StatTray widget.<br><br>"
